package com.air.applets.controller;

import com.air.applets.dto.LandLonLatDto;
import com.air.applets.dto.LandStatisticsDto;
import com.air.applets.entity.ViewLand;
import com.air.applets.service.AppletsMapService;
import com.air.applets.service.ViewLandService;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.cinderella.framework.common.core.util.R;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;


/**
 * 小程序地图显示。
 *
 * @author peihao
 * @date 2021-05-18 09:39:59
 */
@RestController
@RequestMapping("/applets/map")
@Api(value = "appletsMap", tags = "小程序地图显示")
@Slf4j
public class AppletsMapController {

    @Autowired
    private AppletsMapService mapService;

    @Autowired
    private ViewLandService viewLandService;


    /**
     * 查询城市行政区信息
     *
     * @return
     */
    @ApiOperation(value = "查询城市行政区信息", notes = "查询城市行政区信息")
    @GetMapping("getRegionByLocation")
    public R<List<LandLonLatDto>> getRegionByLocation(String city) {
        return R.ok(mapService.getRegionByLocation(city), "查询成功");
    }

    /**
     * 根据定位经纬度返回3公里范围内的设施数据
     *
     * @param lat    纬度
     * @param lon    经度
     * @param radius 范围 默认3000（3公里）
     * @return
     */
    @ApiOperation(value = "根据定位经纬度返回3公里范围内的设施数据", notes = "根据定位经纬度返回3公里范围内的设施数据")
    @GetMapping("getFacilitiesByLocation")
    public R<List<Map<String, String>>> getFacilitiesByLocation(@RequestParam String lat, @RequestParam String lon, Double radius) {
        if (radius == null) {
            radius = 3000d;
        }
        return R.ok(mapService.getFacilitiesByLocation(lat, lon, radius), "查询成功");
    }


    /**
     * 查询城市的大组团和小组团信息
     *
     * @param type 组团类型（表名）
     * @return
     */
    @ApiOperation(value = "查询城市的大组团和小组团信息（typ:dazutuan,xiaozutuan）", notes = "查询城市的大组团和小组团信息（typ:dazutuan,xiaozutuan）")
    @GetMapping("getTypeRegionByLocation")
    public R<List<LandLonLatDto>> getTypeRegionByLocation(@RequestParam String type,String city) {
        log.info("组团类型（表名）=={}===地区 ={}",type,city);
        return R.ok(mapService.getTypeRegionByLocation(type,city), "查询成功");
    }

    /**
     * 查询城市环线数据
     *
     * @return
     */
    @ApiOperation(value = "查询城市环线数据", notes = "查询城市环线数据")
    @GetMapping("getLoopLine")
    public R<List<LandLonLatDto>> getLoopLine(String city) {
        return R.ok(mapService.getLoopLine(city), "查询成功");
    }

    /**
     * 获取城市拟挂牌地块数据
     *
     * @return
     */
    @ApiOperation(value = "获取城市拟挂牌地块数据", notes = "获取城市拟挂牌地块数据")
    @GetMapping("getLandToList")
    public R<List<LandLonLatDto>> getLandToList(String city) {
        return R.ok(mapService.getLandToList(city), "查询成功");
    }

    /**
     * 根据获取城市挂牌中数据
     *
     * @return
     */
    @ApiOperation(value = "根据获取城市挂牌中数据", notes = "根据获取城市挂牌中数据")
    @GetMapping("getLandListing")
    public R<List<LandLonLatDto>> getLandListing(String city) {
        return R.ok(mapService.getLandListing(city), "查询成功");
    }

    /**
     * 根据时间段获取城市出让地块数据
     *
     * @return
     */
    @ApiOperation(value = "获取出让地块数据", notes = "获取出让地块数据")
    @GetMapping("getLandList")
    public R<List<LandLonLatDto>> getLandList(@RequestParam String start, @RequestParam String end,String city) {
        return R.ok(mapService.getLandList(start, end,city), "查询成功");
    }

    @ApiOperation("查询地块城市统计数据")
    @GetMapping("getLandStatisticsOfCity")
    public R<List<LandStatisticsDto>> getLandStatisticsOfCity(){
        return R.ok(viewLandService.getLandStatisticsOfCity(),"查询成功");
    }

    /**
     * 设置行政区，环线，大组团，小组团经纬度
     *
     * @author peihao
     * @date 2021/5/25
     **/
    /*@ApiOperation(value = "设置行政区，环线，大组团，小组团经纬度", notes = "设置行政区，环线，大组团，小组团经纬度")
    @GetMapping(value = "/setGeom/{type}")
    public R setGeom(@PathVariable String type) {
        return R.ok(mapService.setGeom(type));
    }*/

}



































