package com.air.applets.controller;

import cn.hutool.core.util.StrUtil;
import com.air.land.entity.AuctionRecord;
import com.air.land.service.AuctionRecordService;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.cinderella.framework.common.core.util.R;
import com.cinderella.framework.common.data.mybatis.QueryPage;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;


/**
 * 小程序竞拍记录管理
 *
 * @author peihao
 * @date 2021-05-18 09:39:41
 */
@RestController("applets_auctionRecordController")
@AllArgsConstructor
@Validated
@RequestMapping("/applets/auctionRecord")
@Api(value = "auctionRecord", tags = "小程序竞拍记录管理")
public class AuctionRecordController {

    private final AuctionRecordService auctionRecordService;

    /**
     * 查询参拍记录列表
     *
     * @param landListedId 已挂牌地块标识
     * @return
     */
    @ApiOperation(value = "查询参拍记录列表", notes = "查询参拍记录列表")
    @GetMapping("/list")
    public R<IPage<AuctionRecord>> getAuctionRecordPage(QueryPage page, String landListedId) {
        LambdaQueryWrapper<AuctionRecord> query = Wrappers.<AuctionRecord>query().lambda()
                .eq(StrUtil.isNotEmpty(landListedId), AuctionRecord::getLandListedId, landListedId)
                .orderByAsc(AuctionRecord::getSort);
            IPage<AuctionRecord> recordPage = auctionRecordService.page(page.toPage(), query);
        return R.ok(recordPage, "查询成功");
    }
}
