package com.air.applets.controller;

import com.air.applets.dto.BlocksPreSaleTotalDto;
import com.air.housing.service.BlocksService;
import com.cinderella.framework.common.core.util.R;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;


/**
 * 小程序楼盘信息管理
 *
 * @author peihao
 * @date 2021-05-18 09:39:45
 */
@RestController("applets_blocksController")
@AllArgsConstructor
@RequestMapping("/applets/blocks")
@Api(value = "blocks", tags = "小程序楼盘信息管理")
public class BlocksController {

    private final BlocksService blocksService;

    /**
     * 销售情况统计
     *
     * @param landListedId 已挂牌地块id
     * @return R
     */
    @ApiOperation(value = "销售情况统计", notes = "销售情况统计")
    @GetMapping("getPreSaleTotal")
    public R<BlocksPreSaleTotalDto> getPreSaleTotal(@RequestParam String landListedId) {
        return R.ok(blocksService.getPreSaleTotal(landListedId));
    }

    /**
     * 查询预售明细列表
     *
     * @param landListedId 已挂牌地块id
     * @return R
     */
    @ApiOperation(value = "查询预售明细列表", notes = "查询预售明细列表")
    @GetMapping("getPreSaleDetailList")
    public R<List<BlocksPreSaleTotalDto>> getPreSaleDetailList(@RequestParam String landListedId,@RequestParam String buildingName) {
        return R.ok(blocksService.getPreSaleDetailList(landListedId,buildingName));
    }

}
