package com.air.applets.controller;

import cn.hutool.core.util.ObjectUtil;
import com.air.enums.LandListStatusEnum;
import com.air.land.entity.LandToList;
import com.air.land.service.LandToListService;
import com.air.land.vo.LandToListPageVo;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.cinderella.framework.common.core.util.R;
import com.cinderella.framework.common.data.mybatis.QueryPage;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;


/**
 * 小程序拟挂牌地块管理
 *
 * @author peihao
 * @date 2021-05-18 09:40:09
 */
@RestController("applets_landToListController")
@RequestMapping("/applets/landtolist")
@Api(value = "landtolist", tags = "小程序拟挂牌地块管理")
public class LandToListController {

    @Autowired
    private LandToListService landToListService;

    /**
     * 分页查询
     *
     * @param page   分页对象
     * @param pageVo 拟挂牌地块。
     * @return
     */
    @ApiOperation(value = "分页查询", notes = "分页查询")
    @GetMapping
    public R<Page<LandToList>> getLandToListPage(QueryPage page, LandToListPageVo pageVo) {
        Page<LandToList> result = landToListService.page(page.toPage(), Wrappers.<LandToList>query().lambda()
                //供地状态
                .eq(StringUtils.isNotEmpty(pageVo.getSupplyStatus()), LandToList::getSupplyStatus, pageVo.getSupplyStatus())
                //预计挂牌时间
                .eq(StringUtils.isNotEmpty(pageVo.getEstimatedListingTime()), LandToList::getEstimatedListingTime, pageVo.getEstimatedListingTime())
                //地块编号
                .eq(StringUtils.isNotEmpty(pageVo.getLandCode()), LandToList::getLandCode, pageVo.getLandCode())
                //土地用途
                .eq(StringUtils.isNotEmpty(pageVo.getLandUsage()), LandToList::getLandUsage, pageVo.getLandUsage())
                //地质灾害
                .eq(ObjectUtil.isNotEmpty(pageVo.getGeologicHazard()), LandToList::getGeologicHazard, pageVo.getGeologicHazard())
                //人防还建
                .eq(ObjectUtil.isNotEmpty(pageVo.getCivilAirDefence()), LandToList::getCivilAirDefence, pageVo.getCivilAirDefence())
                //特殊规划
                .eq(StringUtils.isNotEmpty(pageVo.getSpecialPlan()), LandToList::getSpecialPlan, pageVo.getSpecialPlan())
                //勾地形式
                .eq(StringUtils.isNotEmpty(pageVo.getHookForm()), LandToList::getHookForm, pageVo.getHookForm())
                //勾地企业
                .eq(StringUtils.isNotEmpty(pageVo.getLandEnterprises()), LandToList::getLandEnterprises, pageVo.getLandEnterprises())
                //出让人
                .eq(StringUtils.isNotEmpty(pageVo.getBargainor()), LandToList::getBargainor, pageVo.getBargainor())
                //城市
                .eq(StringUtils.isNotEmpty(pageVo.getCity()), LandToList::getCity, pageVo.getCity())
                //行政区
                .eq(StringUtils.isNotEmpty(pageVo.getCanton()), LandToList::getCanton, pageVo.getCanton())
                //大组团
                .like(StringUtils.isNotEmpty(pageVo.getBigGroup()), LandToList::getBigGroup, pageVo.getBigGroup())
                //小组团
                .like(StringUtils.isNotEmpty(pageVo.getSmallGroup()), LandToList::getSmallGroup, pageVo.getSmallGroup())
                .orderByDesc(LandToList::getProposedseriaId));
        return R.ok(result, "查询成功");
    }


    /**
     * 通过id查询拟挂牌地块。
     *
     * @param id
     * @return R
     */
    @ApiOperation(value = "通过id查询", notes = "通过id查询")
    @GetMapping("/{id}")
    public R<LandToList> getById(@PathVariable("id") String id) {
        LandToList landToList = landToListService.getById(id);
        if (null == landToList){
            return R.failed("拟挂牌id不正确");
        }
        landToList.setTransactionStatus(LandListStatusEnum.TO_BE_LISTED.getCode());
        return R.ok(landToList);
    }

}
