package com.air.applets.controller;

import com.air.applets.entity.PlanLand;
import com.air.applets.service.PlanLandService;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.cinderella.framework.common.core.util.R;
import com.cinderella.framework.common.data.mybatis.QueryPage;
import com.cinderella.framework.common.security.util.SecurityUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;


/**
 * @author peihao
 * @date 2021-11-25 15:47:04
 */
@RestController
@AllArgsConstructor
@RequestMapping("/planLand")
@Api(value = "planLand", tags = "小程序看地计划管理")
public class PlanLandController {

    private final PlanLandService planLandService;

    /**
     * 分页查询
     *
     * @param page     分页对象
     * @param planLand
     * @return
     */
    @ApiOperation(value = "分页查询", notes = "分页查询")
    @GetMapping("/page")
    public R<IPage<PlanLand>> getPlanLandPage(QueryPage page, PlanLand planLand) {
        planLand.setCreateUserId(SecurityUtils.getUser().getId().toString());
        return R.ok(planLandService.page(page.toPage(), Wrappers.query(planLand).lambda().orderByDesc(PlanLand::getCreateDate)));
    }


    /**
     * 通过id查询
     *
     * @param id id
     * @return R
     */
    @ApiOperation(value = "通过id查询", notes = "通过id查询")
    @GetMapping("/{id}")
    public R<PlanLand> getById(@PathVariable("id") Long id) {
        return R.ok(planLandService.getById(id));
    }

    /**
     * 修改计划
     *
     * @param planLand
     * @return R
     */
    @ApiOperation(value = "修改计划", notes = "修改计划")
    @PutMapping
    public R<Boolean> updateById(@RequestBody PlanLand planLand) {
        return R.ok(planLandService.updateById(planLand));
    }

    /**
     * 通过id删除
     *
     * @param ids ids
     * @return R
     */
    @ApiOperation(value = "通过id删除", notes = "通过id删除")
    @DeleteMapping("removeByIds")
    public R<Boolean> removesPlanAndSpotByIds(@RequestParam List<Integer> ids) {
        return R.ok(planLandService.removesPlanAndSpotByIds(ids), "删除成功");
    }
}
