package com.air.applets.controller;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.StrUtil;
import com.air.cityarea.entity.Report;
import com.air.cityarea.service.ReportService;
import com.air.enums.ReportStatusEnum;
import com.air.enums.ReportTypeEnum;
import com.air.utils.FileUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.cinderella.framework.common.core.util.R;
import com.cinderella.framework.common.data.mybatis.QueryPage;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.*;


/**
 * 小程序土地报告管理
 *
 * @author peihao
 * @date 2021-10-08 17:24:48
 */
@RestController("applets_report")
@AllArgsConstructor
@RequestMapping("/applets/report")
@Api(value = "report", tags = "小程序土地报告管理")
public class ReportController {

    private final ReportService reportService;

    private final FileUtil fileUtil;

    /**
     * 报告分页查询
     *
     * @param page       分页对象
     * @param reportType 报告类型
     * @return
     */
    @ApiOperation(value = "报告分页查询", notes = "报告分页查询(reportType:)")
    @GetMapping("/page")
    public R<IPage<Report>> getReportPage(QueryPage page, @RequestParam(required = false) String reportType, @RequestParam(required = false) String reportName) {
        Page<Report> reportPage = reportService.page(page.toPage(), Wrappers.<Report>query().lambda()
                .eq(StrUtil.isNotEmpty(reportType), Report::getReportType, reportType)
                .like(StrUtil.isNotEmpty(reportName), Report::getReportName, reportName)
                .eq(Report::getStatusCd, "1100")
                .orderByDesc(Report::getCreateDate));
        if (CollectionUtil.isNotEmpty(reportPage.getRecords())) {
            reportPage.getRecords().stream().forEach(e -> {
                e.setFilePath(fileUtil.getUrlByInnerPath(e.getFilePath()));
                e.setReportCoverPath(fileUtil.getUrlByInnerPath(e.getReportCoverPath()));
                e.setReportTypeName(ReportTypeEnum.getName(e.getReportType()));
                e.setStatusName(ReportStatusEnum.getName(e.getStatusCd()));
            });
        }
        return R.ok(reportPage);
    }


    /**
     * 通过id查询土地报告
     *
     * @param id id
     * @return R
     */
    @ApiOperation(value = "通过id查询", notes = "通过id查询")
    @GetMapping("/{id}")
    public R getById(@PathVariable("id") Long id) {
        Report report = reportService.getById(id);
        if (report == null) {
            return R.failed("土地报告id不正确");
        }
        report.setFilePath(fileUtil.getUrlByInnerPath(report.getFilePath()));
        report.setReportCoverPath(fileUtil.getUrlByInnerPath(report.getReportCoverPath()));
        report.setReportTypeName(ReportTypeEnum.getName(report.getReportType()));
        return R.ok(report);
    }

}
