package com.air.applets.convert;

import cn.hutool.core.collection.CollectionUtil;
import com.air.applets.dto.CoordinatePoint;
import com.air.applets.dto.Feature;
import com.air.applets.dto.LandLonLatDto;
import com.air.applets.dto.LandProperties;
import com.air.applets.entity.CityAreaLonLatBase;
import com.air.entity.PolygonGeom;
import com.air.land.entity.LandListedLonLat;
import com.air.utils.GeomUtils;
import org.apache.commons.lang3.StringUtils;

import java.util.ArrayList;
import java.util.List;

/**
 * 地块、经纬度转换
 *
 * @author peihao
 * @date 2021-09-16
 **/
public class LandLonLatConvert {
    /**
     * 地块的信息
     * @param list
     * @param id
     * @return
     */
    public static List<LandLonLatDto> getCityAreaLonLat(List<CityAreaLonLatBase> list, Integer id){
        if (CollectionUtil.isEmpty(list)){
            return null;
        }
        List<LandLonLatDto> landLonLatDtos = new ArrayList<>();
        list.forEach(e ->{
            LandLonLatDto landLonLatDto = new LandLonLatDto();
            landLonLatDto.setName(e.getName());
            CoordinatePoint coordinatePoint = GeomUtils.lonLatConvertPoint(e.getPos());
            PolygonGeom polygonGeom = GeomUtils.computeGemo(coordinatePoint.getPolygonPoints(), e.getLineColor()
                    , e.getLineOpaqueness(), e.getLineWidth(), e.getFillColor(), e.getFillOpaqueness());
            polygonGeom.setId(id);
            landLonLatDto.setPolygon(polygonGeom);
            landLonLatDto.setCenterPoint(coordinatePoint.getCenPoint());//中间点
            landLonLatDtos.add(landLonLatDto);
        });
        return landLonLatDtos;
    }

    public static List<LandLonLatDto> getLandLonLatDto(List<LandListedLonLat> landList, Integer id){
        if (CollectionUtil.isEmpty(landList)){
            return null;
        }
        List<LandLonLatDto> landLonLatDtos = new ArrayList<>();
        landList.forEach(e ->{
            LandLonLatDto landLonLatDto = new LandLonLatDto();

            Feature feature = new Feature();
            LandProperties landProperties = new LandProperties();
            landProperties.setLatId(e.getLatId());
            landProperties.setLandId(e.getLandListedId());
            feature.setProperties(landProperties);
            feature.setId(id);
            if(StringUtils.isNotBlank(e.getLandLonLat())){
                CoordinatePoint coordinatePoint = GeomUtils.lonLatConvertPoint(e.getLandLonLat());
                feature.setCoordinates(coordinatePoint.getCoordinates());
                landLonLatDto.setFeature(feature);
                landLonLatDto.setCenterPoint(coordinatePoint.getCenPoint());

                PolygonGeom polygonGeom = GeomUtils.computeGemo(coordinatePoint.getPolygonPoints(), e.getLineColor(), Integer.valueOf(e.getLineOpaqueness()),
                        Integer.valueOf(e.getLineWidth()), e.getFillColor(), Integer.valueOf(e.getFillOpaqueness()));
                polygonGeom.setId(id);
                landLonLatDto.setPolygon(polygonGeom);
                landLonLatDtos.add(landLonLatDto);
            }

        });
        return landLonLatDtos;
    }
}
