package com.air.applets.service;

import com.air.applets.dto.LandLonLatDto;
import com.air.applets.entity.*;
import com.air.land.entity.LandListedLonLat;
import com.air.land.entity.LandToListLonLat;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;
import java.util.Map;

/**
 * 测算数据
 *
 * @author peihao
 * @date 2021-05-18 09:40:33
 */
public interface AppletsMapService{


    /**
     * 根据定位经纬度范围行政区数据
     * @author peihao
     * @date 2021/6/7
     * @return
     **/
    List<LandLonLatDto> getRegionByLocation(String city);

    /**
     * 根据定位经纬度范围行政区数据
     * @author peihao
     * @param lat 纬度
     * @param lon 经度
     * @param radius 范围 默认3000（3公里）
     * @date 2021/6/7
     * @return
     **/
    List<Map<String, String>> getFacilitiesByLocation(String lat, String lon, Double radius);

    /**
     * 根据定位经纬度返回5公里范围内的大组团小组团
     * @author peihao
     * @param type 组团类型（表名）
     * @date 2021/6/7
     * @return
     **/
    List<LandLonLatDto> getTypeRegionByLocation(String type,String city);

    /**
     * 获取环线数据
     * @author peihao
     * @date 2021/6/7
     * @return
     **/
    List<LandLonLatDto> getLoopLine(String city);

    /**
     * 获取拟挂牌地块数据
     * @author peihao
     * @date 2021/6/7
     * @return
     **/
    List<LandLonLatDto> getLandToList(String city);

    /**
     * 获取挂牌中数据
     * @author peihao
     * @date 2021/6/7
     * @return
     **/
    List<LandLonLatDto> getLandListing(String city);

    /**
     * 获取出让地块数据
     * @author peihao
     * @param start 开始时间
     * @param end 结束时间
     * @date 2021/6/7
     * @return
     **/
    List<LandLonLatDto> getLandList(String start , String end,String city);

    /**
     * 设置行政区，环线，大组团，小组团经纬度
     * @author peihao
     * @param type 1.行政区，2.环线，3.大组团，4.小组团
     * @date 2021/6/7
     * @return
     **/
    boolean setGeom(String type);
}
