package com.air.applets.service.impl;

import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.StrUtil;
import com.air.applets.convert.LandLonLatConvert;
import com.air.applets.dto.LandLonLatDto;
import com.air.applets.entity.*;
import com.air.applets.mapper.AppletsMapMapper;
import com.air.applets.service.AppletsMapService;
import com.air.cityarea.entity.Dazutuan;
import com.air.cityarea.entity.Huanxian;
import com.air.cityarea.entity.Xiaozutuan;
import com.air.cityarea.entity.Xingzhengqu;
import com.air.land.entity.LandListedLonLat;
import com.air.utils.WgsUtil;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;
import java.util.Map;

@Service
@AllArgsConstructor
@Slf4j
public class AppletsMapServiceImpl implements AppletsMapService {

    private AppletsMapMapper mapMapper;

    /**
     * 根据定位经纬度范围行政区数据
     * @param city
     * @return
     */
    @Override
    public List<LandLonLatDto> getRegionByLocation(String city) {
        List<CityAreaLonLatBase> list = mapMapper.getRegionByLocation(city);
        return LandLonLatConvert.getCityAreaLonLat(list,4);
    }

    /**
     * 根据定位经纬度返回3公里范围内的设施数据
     * @param lat 纬度
     * @param lon 经度
     * @param radius 范围 默认3000（3公里）
     * @return
     */
    @Override
    public List<Map<String, String>> getFacilitiesByLocation(String lat, String lon, Double radius) {
        return mapMapper.getFacilitiesByLocation(lat,lon,radius);
    }

    /**
     * 查询城市的大组团和小组团信息
     * @param type 组团类型（表名）
     * @param city
     * @return
     */
    @Override
    public List<LandLonLatDto> getTypeRegionByLocation(String type,String city) {
        List<CityAreaLonLatBase> list = mapMapper.getTypeRegionByLocation(type, city);
        int id = 0;
        if ("dazutuan".equals(type)){
            id = 5;
        }else if ("xiaozutuan".equals(type)){
            id = 6;
        }
        return LandLonLatConvert.getCityAreaLonLat(list,id);
    }

    @Override
    public List<LandLonLatDto> getLoopLine(String city) {
        List<CityAreaLonLatBase> huanxians = mapMapper.getLoopLine(city);
        return LandLonLatConvert.getCityAreaLonLat(huanxians,8);
    }

    @Override
    public List<LandLonLatDto> getLandToList(String city) {
        List<LandListedLonLat> landToList = mapMapper.getLandToList(city);
        return LandLonLatConvert.getLandLonLatDto(landToList,3);
    }

    @Override
    public List<LandLonLatDto> getLandListing(String city) {
        List<LandListedLonLat> landListing = mapMapper.getLandListing(DateUtil.formatDate(new Date()), city);
        return LandLonLatConvert.getLandLonLatDto(landListing,2);
    }

    @Override
    public List<LandLonLatDto> getLandList(String start , String end,String city) {
        List<LandListedLonLat> list = mapMapper.getLandList(start, end, DateUtil.formatDate(new Date()), city);
        return LandLonLatConvert.getLandLonLatDto(list,1);
    }


//    /**
//     * 16进制颜色字符串转换成rgb
//     * @param hexStr
//     * @return rgb
//     */
//    public String hex2RGB(String hexStr,Integer lineOpaqueness){
//        if(hexStr != null && !"".equals(hexStr) && hexStr.length() == 7){
//            int[] rgb = new int[3];
//            rgb[0] = Integer.valueOf(hexStr.substring( 1, 3 ), 16);
//            rgb[1] = Integer.valueOf(hexStr.substring( 3, 5 ), 16);
//            rgb[2] = Integer.valueOf(hexStr.substring( 5, 7 ), 16);
//            String s = Integer.toHexString(lineOpaqueness/100);
//
//            StringBuilder sb = new StringBuilder();
//            sb.append("rgba(");
////遍历int数组，并将int数组中的元素转换成字符串储存到字符缓冲区中去
//            for(int i=0;i < rgb.length;i++)
//            {
//                if(i!=rgb.length-1)
//                    sb.append(rgb[i]+" ,");
//                else
//                    sb.append(rgb[i]+","+s+" )");
//            }
//            log.info("rgb==={}"+sb.toString());
//            return sb.toString();
//        }
//        return null;
//    }// 自定义一个字符缓冲区，


    @Override
    public boolean setGeom(String type) {
        //1.行政区，2.环线，3.大组团，4.小组团
        switch (type){
            case "1":
                List<Xingzhengqu> xingzhengqus = mapMapper.getXingzhengqu();
                for(int i= 0 ;i<xingzhengqus.size();i++){
                    Xingzhengqu xingzhengqu = xingzhengqus.get(i);
                    String geom = WgsUtil.wgs84_To_Gcj02(xingzhengqu.getPos());
                    mapMapper.updateXingzhengqu(geom,xingzhengqu.getId());
                }
                break;
            case "2":
                List<Huanxian> huanxians = mapMapper.getHuanxian();
                for(int i= 0 ;i<huanxians.size();i++){
                    Huanxian huanxian = huanxians.get(i);
                    if(StrUtil.isNotEmpty(huanxian.getPos())){
                        String[] split = huanxian.getPos().split(";");
                        huanxian.setPos(new StringBuffer(huanxian.getPos()).append(";").append(split[0]).toString());
                    }
                    String geom = WgsUtil.wgs84_To_Gcj02(huanxian.getPos());
                    mapMapper.updateHuanxian(geom,huanxian.getId());
                }
                break;
            case "3":
                List<Dazutuan> dazutuans = mapMapper.getDazutuan();
                for(int i= 0 ;i<dazutuans.size();i++){
                    Dazutuan dazutuan = dazutuans.get(i);
                    if(StrUtil.isNotEmpty(dazutuan.getPos())){
                        String[] split = dazutuan.getPos().split(";");
                        dazutuan.setPos(new StringBuffer(dazutuan.getPos()).append(";").append(split[0]).toString());
                    }
                    String geom = WgsUtil.wgs84_To_Gcj02(dazutuan.getPos());
                    mapMapper.updateDazutuan(geom,dazutuan.getId());
                }
                break;
            case "4":
                List<Xiaozutuan> xiaozutuans = mapMapper.getXiaozutuan();
                for(int i= 0 ;i<xiaozutuans.size();i++){
                    Xiaozutuan xiaozutuan = xiaozutuans.get(i);
                    if(StrUtil.isNotEmpty(xiaozutuan.getPos())){
                        String[] split = xiaozutuan.getPos().split(";");
                        xiaozutuan.setPos(new StringBuffer(xiaozutuan.getPos()).append(";").append(split[0]).toString());
                    }
                    String geom = WgsUtil.wgs84_To_Gcj02(xiaozutuan.getPos());
                    mapMapper.updateXiaozutuan(geom,xiaozutuan.getId());
                }
                break;
        }
        return true;
    }
}
