package com.air.applets.service.impl;

import com.air.applets.dto.MeasureStatisticsDto;
import com.air.applets.dto.MeasureTrendDto;
import com.air.applets.entity.MeasureData;
import com.air.applets.mapper.MeasureDataMapper;
import com.air.applets.service.MeasureDataService;
import com.air.utils.DateUtil;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cinderella.framework.common.security.util.SecurityUtils;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.time.LocalDate;
import java.util.List;

/**
 * 测算数据
 *
 * @author peihao
 * @date 2021-05-18 09:40:33
 */
@Service
public class MeasureDataServiceImpl extends ServiceImpl<MeasureDataMapper, MeasureData> implements MeasureDataService {

    @Override
    public MeasureStatisticsDto statistics() {
        String userId = SecurityUtils.getUser().getId().toString();
        MeasureStatisticsDto statisticsDto = new MeasureStatisticsDto();
        //总宗数
        BigDecimal totle = new BigDecimal(this.count());
        if (totle.intValue() == 0) {
            return statisticsDto;
        }
        //测试正确数
        int precisionSum = this.count(Wrappers.<MeasureData>query().lambda()
                .eq(MeasureData::getAccuracy, 1).eq(MeasureData::getCreateUserId, userId));
        //准确率
        BigDecimal precision = new BigDecimal(precisionSum).divide(totle, 2, BigDecimal.ROUND_HALF_UP);
        //误差之和
        BigDecimal absoluteValueSum = baseMapper.getErrorAbsoluteValueSum(userId);
        if (absoluteValueSum != null) {
            //预测误差
            BigDecimal error = absoluteValueSum.divide(totle, 2, BigDecimal.ROUND_HALF_UP);
            statisticsDto.setError(error.doubleValue());
        }
        statisticsDto.setTotle(totle.intValue());
        statisticsDto.setPrecision(precision.doubleValue());
        return statisticsDto;
    }

    @Override
    public List<MeasureTrendDto> trend() {
        String userId = SecurityUtils.getUser().getId().toString();
        //统计时间
        LocalDate now = LocalDate.now();
        String startTime = DateUtil.fromString(now.minusYears(1), "yyyyMM");
        String endTime = DateUtil.fromString(now, "yyyyMM");
        List<MeasureTrendDto> list = baseMapper.getTrend(startTime, endTime, userId);
        for (MeasureTrendDto trend : list) {
            if (trend.getTotal() == 0) {
                continue;
            }
            //平均差值= 溢价率差值/时间宗数
            double value = new BigDecimal(trend.getPremiumSpread()).divide(new BigDecimal(trend.getTotal()), 2, BigDecimal.ROUND_HALF_UP).doubleValue();
            trend.setAverage(value);
        }
        return list;
    }

    @Override
    public Page getMeasureDataPage(Page page, MeasureData measureData) {
        List<MeasureData> measureDataPage = baseMapper.getMeasureDataPage(page, measureData);
        return page.setRecords(measureDataPage);
    }

}
