package com.air.cityarea.controller;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.cinderella.framework.common.core.util.R;
import com.cinderella.framework.common.data.mybatis.QueryPage;
import com.air.cityarea.entity.CityArea;
import com.air.cityarea.service.CityAreaService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;


/**
 * 城市区域配置管理
 *
 * @author peihao
 * @date 2021-09-06 19:11:29
 */
@RestController
@RequestMapping("/cityArea")
@Api(value = "cityArea", tags = "城市区域配置管理")
public class CityAreaController {

    @Autowired
    private CityAreaService cityAreaService;

    @Value("${minio.down-url}")
    private String minioDownUrl;

    @Value("${template.land_listed}")
    private String landListedUrl;

    /**
     * 分页查询城市区域配置
     * @param page 分页对象
     * @param cityArea 
     * @return
     */
    @ApiOperation(value = "分页查询城市区域配置", notes = "分页查询城市区域配置")
    @GetMapping("/page")
    public R getCityAreaPage(QueryPage page, CityArea cityArea) {
        return R.ok(cityAreaService.page(page.toPage(), Wrappers.query(cityArea)));
    }

    /**
     * 查询所有城市
     * @return R
     */
    @ApiOperation(value = "查询所有城市", notes = "查询所有城市")
    @GetMapping("/city")
    public R getCity() {
        return R.ok(cityAreaService.getCity(),"查询成功");
    }

    /**
     * 查询城市的行政区
     * @param city id
     * @return R
     */
    @ApiOperation(value = "查询城市的行政区", notes = "查询城市的行政区")
    @GetMapping("/getArea/{city}")
    public R getArea(@PathVariable("city") String city) {
        return R.ok(cityAreaService.getArea(city),"查询成功");
    }

    /**
     * 查询行政区下的大组团
     * @param area id
     * @return R
     */
    @ApiOperation(value = "查询行政区下的大组团", notes = "查询行政区下的大组团")
    @GetMapping("/getBigGroup")
    public R getBigGroup(@RequestParam("area") String area,@RequestParam("city") String city) {
        return R.ok(cityAreaService.getBigGroup(area,city),"查询成功");
    }

    /**
     * 查询大组团下的小组团
     * @param bigGroup id
     * @return R
     */
    @ApiOperation(value = "查询大组团下的小组团", notes = "查询大组团下的小组团")
    @GetMapping("/getSmallGroup")
    public R getSmallGroup(@RequestParam("bigGroup") String bigGroup,@RequestParam("area") String area,@RequestParam("city") String city) {
        return R.ok(cityAreaService.getSmallGroup(bigGroup,area,city),"查询成功");
    }

    /**
     * 通过id查询城市区域配置
     * @param id id
     * @return R
     */
    @ApiOperation(value = "通过id查询城市区域配置", notes = "通过id查询城市区域配置")
    @GetMapping("/{id}")
    public R getById(@PathVariable("id") Integer id) {
        return R.ok(cityAreaService.getById(id));
    }

    /**
     * 新增城市区域配置
     * @param cityArea 
     * @return R
     */
    @ApiOperation(value = "新增城市区域配置", notes = "新增城市区域配置")
    @PostMapping
    public R save(@RequestBody CityArea cityArea) {
        return R.ok(cityAreaService.save(cityArea));
    }

    /**
     * 修改城市区域配置
     * @param cityArea 
     * @return R
     */
    @ApiOperation(value = "修改城市区域配置", notes = "修改城市区域配置")
    @PutMapping
    public R updateById(@RequestBody CityArea cityArea) {
        if (cityArea.getCity() == null){
            return R.failed("id不能为空！");
        }
        return R.ok(cityAreaService.updateById(cityArea));
    }


    /**
     * 批量删除城市区域
     * @param ids ids
     * @return R
     */
    @ApiOperation(value = "批量删除城市区域", notes = "批量删除城市区域")
    @DeleteMapping("/deleteByIds")
    public R removeById(@RequestParam List<Integer> ids) {
        return R.ok(cityAreaService.removeByIds(ids));
    }

    /**
     * 导入城市区域信息
     *
     * @author peihao
     * @date 2021/5/25
     **/
    @ApiOperation(value = "导入城市区域信息", notes = "导入城市区域信息")
    @PostMapping(value = "/importCityAreaLonLatExcel")
    public R importCityAreaLonLatExcel(@RequestParam(value = "uploadFile") MultipartFile file) {
        return R.ok(cityAreaService.importCityAreaLonLatExcel(file), "导入成功");
    }

    /**
     * 下载城市区域模板
     *
     * @return R
     */
    @ApiOperation(value = "下载城市区域模板", notes = "下载城市区域模板")
    @GetMapping("/getTemplate")
    public R<String> getLandListedTemplate() {
        return R.ok(minioDownUrl + landListedUrl);
    }
}
