package com.air.cityarea.controller;

import cn.hutool.core.util.StrUtil;
import com.air.cityarea.entity.CityArea;
import com.air.cityarea.entity.CityAreaLonLat;
import com.air.cityarea.service.CityAreaLonLatService;
import com.air.cityarea.vo.CityAreaLonLatPageVo;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.cinderella.framework.common.core.util.R;
import com.cinderella.framework.common.data.mybatis.QueryPage;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;


/**
 * 城市区域经纬度
 *
 * @author peihao
 * @date 2021-10-08 17:24:48
 */
@RestController
@AllArgsConstructor
@RequestMapping("/cityAreaLonLat")
@Api(value = "cityAreaLonLat", tags = "城市区域经纬度管理")
public class CityAreaLonLatController {

    private final CityAreaLonLatService cityAreaLonLatService;

    /**
     * 分页查询
     *
     * @param page     分页对象
     * @param pageVo 查询参数
     * @return
     */
    @ApiOperation(value = "分页查询", notes = "分页查询")
    @GetMapping("/page")
    public R<IPage<CityAreaLonLat>> getCityAreaLonLatPage(QueryPage page, CityAreaLonLatPageVo pageVo) {
        if (StrUtil.isEmpty(pageVo.getType())){
            return R.failed("区域类型不能为空");
        }
        if (StrUtil.isEmpty(pageVo.getCity())){
            return R.failed("城市不能为空");
        }
        return R.ok(cityAreaLonLatService.getCityAreaLonLatPage(page, pageVo),"查询成功");
    }


    /**
     * 通过id查询城市区域
     *
     * @param type      区域类型
     * @param primaryId 主键
     * @return R
     */
    @ApiOperation(value = "通过id查询", notes = "通过id查询")
    @GetMapping("getDetail")
    public R<CityAreaLonLat> getDetail(@RequestParam("type") String type, @RequestParam("primaryId") Integer primaryId) {
        return R.ok(cityAreaLonLatService.getDetail(type, primaryId),"查询成功");
    }

    /**
     * 新增城市区域经纬度
     *
     * @param cityAreaLonLat 城市区域经纬度
     * @return R
     */
    @ApiOperation(value = "新增城市区域经纬度", notes = "新增城市区域经纬度")
    @PostMapping
    public R<Boolean> saveAreaLonLat(@RequestBody CityAreaLonLat cityAreaLonLat) {
        return R.ok(cityAreaLonLatService.saveAreaLonLat(cityAreaLonLat),"保存成功");
    }

    /**
     * 修改城市区域经纬度
     *
     * @param cityAreaLonLat 城市区域经纬度
     * @return R
     */
    @ApiOperation(value = "修改城市区域经纬度", notes = "修改城市区域经纬度")
    @PutMapping
    public R<Boolean> updateAreaLonLat(@RequestBody CityAreaLonLat cityAreaLonLat) {
        return R.ok(cityAreaLonLatService.saveAreaLonLat(cityAreaLonLat),"修改成功");
    }

    /**
     * 批量删除城市区域经纬度
     *
     * @param ids ids
     * @return R
     */
    @ApiOperation(value = "批量删除城市区域经纬度", notes = "批量删除城市区域经纬度")
    @DeleteMapping("/deletes")
    public R removes(@RequestParam("type") String type, @RequestParam List<Integer> ids) {
        return R.ok(cityAreaLonLatService.removes(type, ids),"删除成功");
    }

    /**
     * 导入城市区域经纬度信息
     *
     * @author peihao
     * @date 2021/5/25
     **/
    @ApiOperation(value = "导入城市区域经纬度信息", notes = "导入城市区域经纬度信息")
    @PostMapping(value = "/importExcel")
    public R importExcel(@RequestParam(value = "uploadFile") MultipartFile file) {
        return R.ok(cityAreaLonLatService.importExcel(file), "导入成功");
    }

}
