package com.air.cityarea.controller;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.StrUtil;
import com.air.enums.ReportStatusEnum;
import com.air.enums.ReportTypeEnum;
import com.air.utils.FileUtil;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.cinderella.framework.common.core.util.R;
import com.cinderella.framework.common.data.mybatis.QueryPage;
import com.air.cityarea.entity.Report;
import com.air.cityarea.service.ReportService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;


/**
 * 土地报告
 *
 * @author peihao
 * @date 2021-10-08 17:24:48
 */
@RestController
@AllArgsConstructor
@RequestMapping("/report")
@Api(value = "report", tags = "土地报告管理")
public class ReportController {

    private final  ReportService reportService;

    private final FileUtil fileUtil;

    /**
     * 分页查询
     * @param page 分页对象
     * @param report 土地报告
     * @return
     */
    @ApiOperation(value = "分页查询", notes = "分页查询")
    @GetMapping("/page")
    public R getReportPage(QueryPage page, Report report) {
        Page<Report> reportPage = reportService.page(page.toPage(), Wrappers.<Report>query().lambda()
                .eq(StrUtil.isNotEmpty(report.getReportType()),Report::getReportType,report.getReportType())
                .like(StrUtil.isNotEmpty(report.getReportName()),Report::getReportName,report.getReportName())
                .orderByDesc(Report::getCreateDate));
        if (CollectionUtil.isNotEmpty(reportPage.getRecords())){
            reportPage.getRecords().stream().forEach(e -> {
                e.setFilePath(fileUtil.getUrlByInnerPath(e.getFilePath()));
                e.setReportCoverPath(fileUtil.getUrlByInnerPath(e.getReportCoverPath()));
                e.setReportTypeName(ReportTypeEnum.getName(e.getReportType()));
                e.setStatusName(ReportStatusEnum.getName(e.getStatusCd()));
            });
        }
        return R.ok(reportPage);
    }


    /**
     * 通过id查询土地报告
     * @param id id
     * @return R
     */
    @ApiOperation(value = "通过id查询", notes = "通过id查询")
    @GetMapping("/{id}")
    public R getById(@PathVariable("id") Long id) {
        Report report = reportService.getById(id);
        if(report == null ){
            return R.failed("id正确");
        }
        report.setFilePath(fileUtil.getUrlByInnerPath(report.getFilePath()));
        report.setReportCoverPath(fileUtil.getUrlByInnerPath(report.getReportCoverPath()));
        report.setReportTypeName(ReportTypeEnum.getName(report.getReportType()));
        return R.ok(report);
    }

    /**
     * 新增土地报告
     * @param report 土地报告
     * @return R
     */
    @ApiOperation(value = "新增土地报告", notes = "新增土地报告")
    @PostMapping
    public R save(@RequestBody Report report) {
        return R.ok(reportService.save(report));
    }

    /**
     * 修改土地报告
     * @param report 土地报告
     * @return R
     */
    @ApiOperation(value = "修改土地报告", notes = "修改土地报告")
    @PutMapping
    public R updateById(@RequestBody Report report) {
        if (report.getId() == null){
            return R.failed("id不能为空");
        }
        report.setFilePath(fileUtil.getInnerPath(report.getFilePath()));
        report.setReportCoverPath(fileUtil.getInnerPath(report.getReportCoverPath()));
        return R.ok(reportService.updateById(report));
    }

    /**
     * 通过id删除土地报告
     * @param ids ids
     * @return R
     */
    @ApiOperation(value = "通过id删除土地报告", notes = "通过id删除土地报告")
    @DeleteMapping("deleteByIds")
    public R removeById(@RequestParam List<Long> ids) {
        return R.ok(reportService.removeByIds(ids));
    }
}
