package com.air.cityarea.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.StrUtil;
import com.air.cityarea.entity.*;
import com.air.cityarea.mapper.*;
import com.air.cityarea.service.*;
import com.air.cityarea.vo.CityAreaLonLatPageVo;
import com.air.enums.CityAreaEnum;
import com.air.utils.ExcelUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cinderella.framework.common.core.exception.BusinessException;
import com.cinderella.framework.common.data.mybatis.QueryPage;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.util.ArrayList;
import java.util.List;

/**
 * 城市区域经纬度
 *
 * @author peihao
 * @date 2021-10-08 17:24:48
 */
@Service
@AllArgsConstructor
@Slf4j
public class CityAreaLonLatServiceImpl implements CityAreaLonLatService {

    private DazutuanService dazutuanService;

    private XiaozutuanService xiaozutuanService;

    private XingzhengquService xingzhengquService;

    private HuanxianService huanxianService;

    @Override
    public IPage<CityAreaLonLat> getCityAreaLonLatPage(QueryPage page, CityAreaLonLatPageVo pageVo) {
        IPage<CityAreaLonLat> resultPage = new Page();
        switch (pageVo.getType()){
            case "area":
                IPage<Xingzhengqu> xingzhengquPage = xingzhengquService.page(page.toPage(), Wrappers.<Xingzhengqu>query().lambda()
                        .eq(Xingzhengqu::getCity,pageVo.getCity()).like(StrUtil.isNotEmpty(pageVo.getName()), Xingzhengqu::getName, pageVo.getName()));
                xingzhengquPage.getRecords().stream().forEach(item ->item.setType("area"));
                BeanUtil.copyProperties(xingzhengquPage,resultPage);
                break;
            case "bigGroup":
                IPage<Dazutuan> dazutuanPage = dazutuanService.page(page.toPage(), Wrappers.<Dazutuan>query().lambda()
                        .eq(Dazutuan::getCity,pageVo.getCity()).like(StrUtil.isNotEmpty(pageVo.getName()), Dazutuan::getName, pageVo.getName()));
                dazutuanPage.getRecords().stream().forEach(item ->item.setType("bigGroup"));
                BeanUtil.copyProperties(dazutuanPage,resultPage);
                break;
            case "smallGroup":
                IPage<Xiaozutuan> xiaozutuanPage = xiaozutuanService.page(page.toPage(), Wrappers.<Xiaozutuan>query().lambda()
                        .eq(Xiaozutuan::getCity,pageVo.getCity()).like(StrUtil.isNotEmpty(pageVo.getName()), Xiaozutuan::getName, pageVo.getName()));
                xiaozutuanPage.getRecords().stream().forEach(item ->item.setType("smallGroup"));
                BeanUtil.copyProperties(xiaozutuanPage,resultPage);

                break;
            case "loop":
                IPage<Huanxian> huanxianPage = huanxianService.page(page.toPage(), Wrappers.<Huanxian>query().lambda()
                        .eq(Huanxian::getCity,pageVo.getCity()).like(StrUtil.isNotEmpty(pageVo.getName()), Huanxian::getName, pageVo.getName()));
                huanxianPage.getRecords().stream().forEach(item ->item.setType("loop"));
                BeanUtil.copyProperties(huanxianPage,resultPage);
                break;
        }
        return resultPage;
    }

    @Override
    public CityAreaLonLat getDetail(String type, Integer primaryId) {
        CityAreaLonLat cityAreaLonLat = new CityAreaLonLat();
        switch (type){
            case "area":
                Xingzhengqu xingzhengqu = xingzhengquService.getById(primaryId);
                BeanUtil.copyProperties(xingzhengqu,cityAreaLonLat);
                break;
            case "bigGroup":
                Dazutuan dazutuan = dazutuanService.getById(primaryId);
                BeanUtil.copyProperties(dazutuan,cityAreaLonLat);
                break;
            case "smallGroup":
                Xiaozutuan xiaozutuan = xiaozutuanService.getById(primaryId);
                BeanUtil.copyProperties(xiaozutuan,cityAreaLonLat);
                break;
            case "loop":
                Huanxian huanxian = huanxianService.getById(primaryId);
                BeanUtil.copyProperties(huanxian,cityAreaLonLat);
                break;
        }
        return cityAreaLonLat;
    }

    @Override
    public boolean saveAreaLonLat(CityAreaLonLat cityAreaLonLat) {
        switch (cityAreaLonLat.getType()){
            case "area":
                Xingzhengqu xingzhengqu = new Xingzhengqu();
                BeanUtil.copyProperties(cityAreaLonLat,xingzhengqu);
                xingzhengqu.setId(cityAreaLonLat.getId());
                xingzhengquService.saveOrUpdate(xingzhengqu);
                break;
            case "bigGroup":
                Dazutuan dazutuan = new Dazutuan();
                BeanUtil.copyProperties(cityAreaLonLat,dazutuan);
                dazutuan.setId(cityAreaLonLat.getId());
                dazutuanService.saveOrUpdate(dazutuan);
                break;
            case "smallGroup":
                Xiaozutuan xiaozutuan = new Xiaozutuan();
                BeanUtil.copyProperties(cityAreaLonLat,xiaozutuan);
                xiaozutuan.setId(cityAreaLonLat.getId());
                xiaozutuanService.saveOrUpdate(xiaozutuan);
                break;
            case "loop":
                Huanxian huanxian = new Huanxian();
                BeanUtil.copyProperties(cityAreaLonLat,huanxian);
                huanxian.setId(cityAreaLonLat.getId());
                huanxianService.saveOrUpdate(huanxian);
                break;
        }
        return true;
    }

    @Override
    public boolean updateAreaLonLat(CityAreaLonLat cityAreaLonLat) {
        return false;
    }

    @Override
    public boolean removes(String type, List<Integer> ids) {
        switch (type){
            case "area":
                xingzhengquService.removeByIds(ids);
                break;
            case "bigGroup":
                dazutuanService.removeByIds(ids);
                break;
            case "smallGroup":
                xiaozutuanService.removeByIds(ids);
                break;
            case "loop":
                huanxianService.removeByIds(ids);
                break;
        }
        return true;
    }

    @Override
    public boolean importExcel(MultipartFile file) {
        List<CityAreaLonLat> dataList;
        try {
            dataList = ExcelUtil.importExcel(file.getInputStream(), 0, 0, 0, CityAreaLonLat.class, "config/cityAreaLonLat-config.json");
        } catch (Exception e) {
            log.error("导入城市区域经纬度出错", e);
            throw new BusinessException("导入城市区域经纬度出错");
        }
        if (CollectionUtil.isNotEmpty(dataList)){
            switch (dataList.get(0).getType()){
                case "行政区":
                    List<Xingzhengqu> xingzhengqus = new ArrayList<>();
                    dataList.stream().forEach(item ->{
                        Xingzhengqu xingzhengqu = new Xingzhengqu();
                        BeanUtil.copyProperties(item,xingzhengqu);
                        xingzhengqus.add(xingzhengqu);
                    });
                    xingzhengquService.saveBatch(xingzhengqus);
                    break;
                case "大组团":
                    List<Dazutuan> dazutuans = new ArrayList<>();
                    dataList.stream().forEach(item ->{
                        Dazutuan dazutuan = new Dazutuan();
                        BeanUtil.copyProperties(item,dazutuan);
                        dazutuans.add(dazutuan);
                    });
                    dazutuanService.saveBatch(dazutuans);
                    break;
                case "小组团":
                    List<Xiaozutuan> xiaozutuans = new ArrayList<>();
                    dataList.stream().forEach(item ->{
                        Xiaozutuan xiaozutuan = new Xiaozutuan();
                        BeanUtil.copyProperties(item,xiaozutuan);
                        xiaozutuans.add(xiaozutuan);
                    });
                    xiaozutuanService.saveBatch(xiaozutuans);
                    break;
                case "环线":
                    List<Huanxian> huanxians = new ArrayList<>();
                    dataList.stream().forEach(item ->{
                        Huanxian huanxian = new Huanxian();
                        BeanUtil.copyProperties(item,huanxian);
                        huanxians.add(huanxian);
                    });
                    huanxianService.saveBatch(huanxians);
                    break;
            }

        }
        return true;
    }
}
