package com.air.controller;

import com.air.entity.Building;
import com.air.service.BuildingService;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.cinderella.framework.common.core.util.R;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;


/**
 * @author peihao
 * @date 2021-05-18 09:39:31
 */
@RestController
@AllArgsConstructor
@RequestMapping("/building")
@Api(value = "building", tags = "管理")
public class BuildingController {

    private final BuildingService buildingService;

    /**
     * 分页查询
     *
     * @param page     分页对象
     * @param building
     * @return
     */
    @ApiOperation(value = "分页查询", notes = "分页查询")
    @GetMapping("/page")
    public R getBuildingPage(Page page, Building building) {
        return R.ok(buildingService.page(page, Wrappers.query(building)));
    }


    /**
     * 通过id查询
     *
     * @param id id
     * @return R
     */
    @ApiOperation(value = "通过id查询", notes = "通过id查询")
    @GetMapping("/{id}")
    public R getById(@PathVariable("id") Long id) {
        return R.ok(buildingService.getById(id));
    }

    /**
     * 新增
     *
     * @param building
     * @return R
     */
    @ApiOperation(value = "新增", notes = "新增")
    @PostMapping
    @PreAuthorize("@pms.hasPermission('generator_building_add')")
    public R save(@RequestBody Building building) {
        return R.ok(buildingService.save(building));
    }

    /**
     * 修改
     *
     * @param building
     * @return R
     */
    @ApiOperation(value = "修改", notes = "修改")
    @PutMapping
    @PreAuthorize("@pms.hasPermission('generator_building_edit')")
    public R updateById(@RequestBody Building building) {
        return R.ok(buildingService.updateById(building));
    }

    /**
     * 通过id删除
     *
     * @param id id
     * @return R
     */
    @ApiOperation(value = "通过id删除", notes = "通过id删除")
    @DeleteMapping("/{id}")
    @PreAuthorize("@pms.hasPermission('generator_building_del')")
    public R removeById(@PathVariable Long id) {
        return R.ok(buildingService.removeById(id));
    }
}
