package com.air.controller;

import com.air.entity.LandTransaction;
import com.air.service.LandTransactionService;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.cinderella.framework.common.core.util.R;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;


/**
 * @author peihao
 * @date 2021-05-18 09:39:25
 */
@RestController
@AllArgsConstructor
@RequestMapping("/landtransaction")
@Api(value = "landtransaction", tags = "管理")
public class LandTransactionController {

    private final LandTransactionService landTransactionService;

    /**
     * 分页查询
     *
     * @param page            分页对象
     * @param landTransaction
     * @return
     */
    @ApiOperation(value = "分页查询", notes = "分页查询")
    @GetMapping("/page")
    public R getLandTransactionPage(Page page, LandTransaction landTransaction) {
        return R.ok(landTransactionService.page(page, Wrappers.query(landTransaction)));
    }


    /**
     * 通过id查询
     *
     * @param id id
     * @return R
     */
    @ApiOperation(value = "通过id查询", notes = "通过id查询")
    @GetMapping("/{id}")
    public R getById(@PathVariable("id") Long id) {
        return R.ok(landTransactionService.getById(id));
    }

    /**
     * 新增
     *
     * @param landTransaction
     * @return R
     */
    @ApiOperation(value = "新增", notes = "新增")
    @PostMapping
    @PreAuthorize("@pms.hasPermission('generator_landtransaction_add')")
    public R save(@RequestBody LandTransaction landTransaction) {
        return R.ok(landTransactionService.save(landTransaction));
    }

    /**
     * 修改
     *
     * @param landTransaction
     * @return R
     */
    @ApiOperation(value = "修改", notes = "修改")
    @PutMapping
    @PreAuthorize("@pms.hasPermission('generator_landtransaction_edit')")
    public R updateById(@RequestBody LandTransaction landTransaction) {
        return R.ok(landTransactionService.updateById(landTransaction));
    }

    /**
     * 通过id删除
     *
     * @param id id
     * @return R
     */
    @ApiOperation(value = "通过id删除", notes = "通过id删除")
    @DeleteMapping("/{id}")
    @PreAuthorize("@pms.hasPermission('generator_landtransaction_del')")
    public R removeById(@PathVariable Long id) {
        return R.ok(landTransactionService.removeById(id));
    }
}
