package com.air.controller;

import com.air.entity.RoomState;
import com.air.service.RoomStateService;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.cinderella.framework.common.core.util.R;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;


/**
 * @author peihao
 * @date 2021-05-18 09:38:20
 */
@RestController
@AllArgsConstructor
@RequestMapping("/roomstate")
@Api(value = "roomstate", tags = "管理")
public class RoomStateController {

    private final RoomStateService roomStateService;

    /**
     * 分页查询
     *
     * @param page      分页对象
     * @param roomState
     * @return
     */
    @ApiOperation(value = "分页查询", notes = "分页查询")
    @GetMapping("/page")
    public R getRoomStatePage(Page page, RoomState roomState) {
        return R.ok(roomStateService.page(page, Wrappers.query(roomState)));
    }


    /**
     * 通过id查询
     *
     * @param id id
     * @return R
     */
    @ApiOperation(value = "通过id查询", notes = "通过id查询")
    @GetMapping("/{id}")
    public R getById(@PathVariable("id") Long id) {
        return R.ok(roomStateService.getById(id));
    }

    /**
     * 新增
     *
     * @param roomState
     * @return R
     */
    @ApiOperation(value = "新增", notes = "新增")
    @PostMapping
    @PreAuthorize("@pms.hasPermission('generator_roomstate_add')")
    public R save(@RequestBody RoomState roomState) {
        return R.ok(roomStateService.save(roomState));
    }

    /**
     * 修改
     *
     * @param roomState
     * @return R
     */
    @ApiOperation(value = "修改", notes = "修改")
    @PutMapping
    @PreAuthorize("@pms.hasPermission('generator_roomstate_edit')")
    public R updateById(@RequestBody RoomState roomState) {
        return R.ok(roomStateService.updateById(roomState));
    }

    /**
     * 通过id删除
     *
     * @param id id
     * @return R
     */
    @ApiOperation(value = "通过id删除", notes = "通过id删除")
    @DeleteMapping("/{id}")
    @PreAuthorize("@pms.hasPermission('generator_roomstate_del')")
    public R removeById(@PathVariable Long id) {
        return R.ok(roomStateService.removeById(id));
    }
}
