package com.air.facilities.controller;

import com.air.facilities.dto.FacilitiesDTO;
import com.air.facilities.entity.Facilities;
import com.air.facilities.service.FacilitiesService;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.cinderella.framework.common.core.exception.BusinessException;
import com.cinderella.framework.common.core.util.R;
import com.cinderella.framework.common.data.mybatis.QueryPage;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.util.List;

/**
 * @program: back-end
 * @description:
 * @author: cyz
 * @create: 2022-07-07 15:49
 **/
@RestController
@RequestMapping("/facilities")
@Api(tags = "城市周边")
@Slf4j
public class FacilitiesController {

    @Autowired
    private FacilitiesService facilitiesService;


    @ApiOperation(value = "添加")
    @PostMapping("/add")
    public R<Facilities> addFacilities(@RequestBody FacilitiesDTO facilitiesDTO){
        log.info("-----------------------------------"+facilitiesDTO);
        facilitiesService.addFacilities(facilitiesDTO);
        return R.ok();
    }

    @ApiOperation(value = "修改")
    @PutMapping("/update")
    public R<Facilities> updateFacilities(@RequestBody FacilitiesDTO facilitiesDTO){
        log.info("===================="+facilitiesDTO);
        facilitiesService.updateFacilities(facilitiesDTO);
        return R.ok();
    }
    @ApiOperation(value = "查询全部")
    @GetMapping("/list")
    public R<Page<Facilities>> selectFacilitiesList(QueryPage queryPage, FacilitiesDTO facilitiesDTO){
        log.info(""+facilitiesDTO);
        Page<Facilities> page = queryPage.toPage();
        List<Facilities> facilities1 = facilitiesService.selectAllFacilitiesPage(page, facilitiesDTO);
        return R.ok(page.setRecords(facilities1), "查询成功");
    }

    @ApiOperation(value = "查询城市地区")
    @GetMapping("/list/rim")
    public R<Page<Facilities>> selectFacilitiesRim(QueryPage queryPage,FacilitiesDTO facilitiesDTO){
        Page<Facilities> page = queryPage.toPage();
        log.info("{}",facilitiesDTO);
        List<Facilities> facilities1 = facilitiesService.selectAllFacilitiesRim(page,facilitiesDTO);
        return R.ok(page.setRecords(facilities1), "查询成功");
    }

    @ApiOperation(value = "根据ID查询")
    @GetMapping("/list/{id}")
    public R<Facilities> selectFacilitiesId(@PathVariable("id") String id){

        return R.ok();
    }
    @ApiOperation(value = "删除")
    @DeleteMapping("/delete/{ids}")
    public R<Facilities> deleteFacilities(@PathVariable String[] ids){
        int i = facilitiesService.deleteFacilities(ids);
        return i > 0 ? R.ok() : R.failed("删除失败！");
    }



    @ApiOperation(value = "删除指定城市周边数据")
    @DeleteMapping("/deleteRim")
    public R<Facilities> deleteFacilitiesRim(@RequestBody FacilitiesDTO facilitiesDTO){
        log.info("======={}=======",facilitiesDTO);
        int i = facilitiesService.deleteFacilitiesRim(facilitiesDTO);
        return i > 0 ? R.ok() : R.failed("删除失败！");
    }

    @ApiOperation(value = "查询城市市")
    @GetMapping("/selectTypeList")
    public R<List<Facilities>> selectTypeList(){
        List<Facilities> facilities = facilitiesService.selectTypeList();
        return R.ok(facilities);
    }

    @ApiOperation(value = "导入周边信息")
    @PostMapping("/importFile")
    public R<String> importFile(@RequestParam(value = "uploadFile") MultipartFile file){
        try {
            int i = facilitiesService.importFile(file);
            switch (i){
                case 0:
                    return R.failed("导入失败！");
                case 1:
                    return R.ok();
                case 10:
                    return R.failed("导入文件格式不正确！请上传后缀为.xlsx");
            }
            return R.failed();
        }catch (BusinessException be) {
            be.printStackTrace();
            return R.failed("导入失败！"+be.getMessage());
        } catch (IOException e) {
            e.printStackTrace();
            return R.failed();
        }

    }


}
