package com.air.facilities.service.impl;

import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.air.baseRegion.mapper.BaseRegionMapper;
import com.air.dictitem.entity.DictItem;
import com.air.dictitem.mapper.DictItemMapper;
import com.air.facilities.dto.FacilitiesDTO;
import com.air.facilities.dto.FacilitiesFileDTO;
import com.air.facilities.entity.Facilities;
import com.air.facilities.mapper.FacilitiesMapper;
import com.air.facilities.service.FacilitiesService;
import com.alibaba.excel.EasyExcel;
import com.alibaba.excel.read.listener.PageReadListener;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cinderella.framework.common.core.exception.BusinessException;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.concurrent.ThreadPoolTaskExecutor;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.io.InputStream;
import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @program: back-end
 * @description:
 * @author: cyz
 * @create: 2022-07-07 15:44
 **/
@Slf4j
@Service
public class FacilitiesServiceImpl extends ServiceImpl<FacilitiesMapper, Facilities> implements FacilitiesService {

    @Autowired
    private FacilitiesMapper facilitiesMapper;

    @Autowired
    private BaseRegionMapper baseRegionMapper;

    @Autowired
    private DictItemMapper dictItemMapper;
    @Autowired
    ThreadPoolTaskExecutor executor;

    /**
     * 查询全部数据
     *
     * @param facilitiesDTO
     * @return
     */
    @Override
    public List<Facilities> selectAllFacilitiesPage(Page page, FacilitiesDTO facilitiesDTO) {
        Facilities facilities = new Facilities();
        BeanUtils.copyProperties(facilitiesDTO,facilities);
        facilities.setCity(facilitiesDTO.getUrban());
//        log.info("=========={}",facilities);
        List<Facilities> allFacilities = facilitiesMapper.getAllFacilities(page, facilities);
        return allFacilities;
    }

    /**
     * 查询全部地区
     * @param page
     * @param facilitiesDTO
     * @return
     */
    @Override
    public List<Facilities> selectAllFacilitiesRim(Page page, FacilitiesDTO facilitiesDTO) {
        if(facilitiesDTO.getMarking().equals("2")){
            return facilitiesMapper.getAllFacilitiesRimShi(page);
        }
        return facilitiesMapper.getAllFacilitiesRim(page);
    }

    /**
     * 根据ID查询具体信息
     *
     * @param id
     * @return
     */
    @Override
    public Facilities getFacilitiesId(String id) {
        Facilities facilities = facilitiesMapper.selectById(id);
        return facilities;
    }

    /**
     * 修改周边信息
     *
     * @param facilities
     * @return
     */
    @Override
    public int putFacilities(Facilities facilities) {

        return facilitiesMapper.update(facilities, null);
    }

    /**
     * 删除周边信息
     *
     * @param ids@return
     */
    @Override
    public int deleteFacilities(String[] ids) {
        return facilitiesMapper.delFacilities(ids);
    }

    /**
     * 删除指定城市周边信息
     * @param facilitiesDTO
     * @return
     */
    @Override
    public int deleteFacilitiesRim(FacilitiesDTO facilitiesDTO) {
        List<Facilities> facilitiesList = new ArrayList<>();
        if(StrUtil.isNotBlank(facilitiesDTO.getCounty())){
            facilitiesList = facilitiesMapper.selectList(Wrappers.<Facilities>query().lambda()
                    .eq(StringUtils.isNotBlank(facilitiesDTO.getSite()), Facilities::getSite, facilitiesDTO.getSite())
                    .eq(StringUtils.isNotBlank(facilitiesDTO.getCity()), Facilities::getCity, facilitiesDTO.getCity())
                    .eq(StringUtils.isNotBlank(facilitiesDTO.getCounty()), Facilities::getCounty, facilitiesDTO.getCounty())
            );
        }else{
            facilitiesList = facilitiesMapper.selectList(Wrappers.<Facilities>query().lambda()
                    .eq(StringUtils.isNotBlank(facilitiesDTO.getSite()), Facilities::getSite, facilitiesDTO.getSite())
                    .eq(StringUtils.isNotBlank(facilitiesDTO.getCity()), Facilities::getCity, facilitiesDTO.getCity())
            );
        }

        log.info("{}",facilitiesList.size());
        List<String> list = new ArrayList<>();
        facilitiesList.forEach(ids ->{
            list.add(ids.getGid().toString());
        });
       // log.info("id============{}",list);
        String[] array = list.toArray(new String[list.size()]);
        //删除
        return facilitiesMapper.delFacilities(array);
    }

    /**
     * 添加
     *
     * @param facilitiesDTO
     * @return
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int addFacilities(FacilitiesDTO facilitiesDTO) {
        Facilities facilities = new Facilities();
        BeanUtils.copyProperties(facilitiesDTO, facilities);
        String srt = "POINT(" + facilitiesDTO.getLon() + " " + facilitiesDTO.getLat() + ")";
        facilities.setGeom(srt);
        if (StrUtil.isNotBlank(facilitiesDTO.getOldType())) {
            DictItem rim = dictItemMapper.selectOne(Wrappers.<DictItem>query().lambda()
                    .eq(StringUtils.isNotEmpty(facilitiesDTO.getOldType()), DictItem::getValue, facilitiesDTO.getOldType())
                    .eq(DictItem::getType, "rim")
            );
            if (ObjectUtil.isNotNull(rim)) {
                facilities.setType(rim.getValue());
                facilities.setTypecn(rim.getLabel());
                return facilitiesMapper.insertFacilities(facilities);
            }else{
                return 0;
            }
        }else{
            return 0;
        }
    }

    /**
     * 查询城市市
     *
     * @return
     */
    @Override
    public List<Facilities> selectTypeList() {

        return facilitiesMapper.selectTypeList();
    }

    /**
     * 修改
     *
     * @param facilitiesDTO
     * @return
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateFacilities(FacilitiesDTO facilitiesDTO) {
        Facilities facilities = new Facilities();
        BeanUtils.copyProperties(facilitiesDTO, facilities);
        String srt = "POINT(" + facilitiesDTO.getLon() + " " + facilitiesDTO.getLat() + ")";
        facilities.setGeom(srt);
        facilities.setGid(facilitiesDTO.getGid());
        if (StrUtil.isNotBlank(facilitiesDTO.getOldType())) {
            DictItem rim = dictItemMapper.selectOne(Wrappers.<DictItem>query().lambda()
                    .eq(StringUtils.isNotEmpty(facilitiesDTO.getOldType()), DictItem::getValue, facilitiesDTO.getOldType())
                    .eq(DictItem::getType, "rim")
            );
            if (ObjectUtil.isNotNull(rim)) {
                facilities.setType(rim.getValue());
                facilities.setTypecn(rim.getLabel());
                return facilitiesMapper.updateFacilities(facilities);
            }else{
                return 0;
            }
        }else{
            return 0;
        }

    }

    /**
     * 导入周边信息
     *
     * @param file
     * @return
     */
    @Override
    @Transactional
    public int importFile(MultipartFile file) {
        try {
            //判断文件类型是否正确
            String originalFilename = file.getOriginalFilename();
            String fileType = originalFilename.substring(originalFilename.lastIndexOf("."));
            if (!".xls".equalsIgnoreCase(fileType) && !".xlsx".equalsIgnoreCase(fileType)) {
               return 10;
            }
            InputStream inputStream = file.getInputStream();

            SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            log.info("{},开始导入数据...", format.format(new Date()));
//            EasyExcel.read(inputStream, FacilitiesFileDTO.class, new FacilitiesListener(dictItemMapper,baseRegionMapper,facilitiesMapper,executor)
            List<Facilities> facilitiesList = new ArrayList<>();
            EasyExcel.read(inputStream, FacilitiesFileDTO.class, new PageReadListener<FacilitiesFileDTO>
               ( dataList -> {
                   log.info("====================={}条数据",dataList.size());
                       dataList.forEach( demoData -> {

                           Facilities facilities = new Facilities();
                           facilities.setName(demoData.getName());
                           String[] split = demoData.getNautica().split(",");
                           String srt = "POINT(" + split[0] + " " + split[1] + ")";
                           String s = split[0];
                           BigDecimal bd=new BigDecimal(s);
                           facilities.setLon(bd);//经度
                           String se = split[1];
                           BigDecimal bed=new BigDecimal(se);
                           facilities.setLat(bed);//纬度
                           facilities.setGeom(srt);
                           //查询周边类型
                           DictItem rim = dictItemMapper.selectOne(Wrappers.<DictItem>query().lambda()
                                   .like(StringUtils.isNotBlank(demoData.getClassify()), DictItem::getLabel, demoData.getClassifyTwo())
                                   .eq(DictItem::getType, "rim")
                           );
                           if(ObjectUtil.isNotNull(rim) ){
                               facilities.setType(rim.getValue());
                               facilities.setTypecn(rim.getLabel());
                           }else{
                               throw new BusinessException("没有该分类");
                           }
                           //查询地区ID

                           facilities.setSite(demoData.getProvince());
                           facilities.setCounty(demoData.getArea());
                           facilities.setCity(demoData.getCity());
                           if(StringUtils.isNotBlank(demoData.getAddress())){
                               facilities.setAddress(demoData.getAddress());
                           }
                           facilitiesList.add(facilities);
                       });

            })
            ).sheet().headRowNumber(1).doRead();
            facilitiesMapper.insertFacilitiesList(facilitiesList);
            log.info("==========插入的数量{}",facilitiesList.size());
            facilitiesList.clear();
            return 1;
        } catch (IOException e) {
            e.printStackTrace();
        }
        return 0;
    }


}
