package com.air.housing.controller;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.cinderella.framework.common.core.util.R;
import com.air.housing.entity.Format;
import com.air.housing.service.FormatService;
import com.cinderella.framework.common.data.mybatis.QueryPage;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.*;


/**
 * 业态信息
 *
 * @author zeb
 * @date 2021-06-09 09:13:16
 */
@RestController
@AllArgsConstructor
@RequestMapping("/format")
@Api(value = "format", tags = "业态信息管理")
public class FormatController {

    private final  FormatService formatService;

    /**
     * 分页查询
     * @param page 分页对象
     * @param format 业态信息
     * @return
     */
    @ApiOperation(value = "分页查询", notes = "分页查询")
    @GetMapping("/page")
    public R getFormatPage(QueryPage page, Format format) {
        return R.ok(formatService.page(page.toPage(), Wrappers.query(format)));
    }


    /**
     * 通过id查询业态信息
     * @param formatId id
     * @return R
     */
    @ApiOperation(value = "通过id查询", notes = "通过id查询")
    @GetMapping("/{formatId}")
    public R getById(@PathVariable("formatId") Long formatId) {
        return R.ok(formatService.getById(formatId));
    }

    /**
     * 新增业态信息
     * @param format 业态信息
     * @return R
     */
    @ApiOperation(value = "新增业态信息", notes = "新增业态信息")
    @PostMapping
    public R save(@RequestBody Format format) {
        return R.ok(formatService.save(format));
    }

    /**
     * 修改业态信息
     * @param format 业态信息
     * @return R
     */
    @ApiOperation(value = "修改业态信息", notes = "修改业态信息")
    @PutMapping
    public R updateById(@RequestBody Format format) {
        return R.ok(formatService.updateBy(format));
    }

    /**
     * 通过id删除业态信息
     * @param formatId id
     * @return R
     */
    @ApiOperation(value = "通过id删除业态信息", notes = "通过id删除业态信息")
    @DeleteMapping("/{formatId}")
    public R removeById(@PathVariable Long formatId) {
        return R.ok(formatService.removeById(formatId));
    }
}
