package com.air.housing.service.impl;

import cn.hutool.core.collection.CollectionUtil;
import com.air.applets.dto.BlocksPreSaleTotalDto;
import com.air.housing.dto.BlockListDto;
import com.air.housing.entity.AnnoBlocksRel;
import com.air.housing.entity.Blocks;
import com.air.housing.entity.Format;
import com.air.housing.entity.HousingEstates;
import com.air.housing.mapper.AnnoBlocksRelMapper;
import com.air.housing.mapper.BlocksMapper;
import com.air.housing.mapper.FormatMapper;
import com.air.housing.mapper.HousingEstatesMapper;
import com.air.housing.service.BlocksService;
import com.air.housing.vo.BlocksVO;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

/**
 * 楼栋信息
 *
 * @author peihao
 * @date 2021-05-18 09:39:45
 */
@Service
@AllArgsConstructor
@Slf4j
public class BlocksServiceImpl extends ServiceImpl<BlocksMapper, Blocks> implements BlocksService {

    private BlocksMapper blocksMapper;

    private AnnoBlocksRelMapper annoBlocksRelMapper;

    @Autowired
    private HousingEstatesMapper housingEstatesMapper;

    @Autowired
    private FormatMapper formatMapper;

    @Override
    public Page<Blocks> getBlocksPageByhousingEstateId(Page page, BlockListDto blockListDto) {
        return blocksMapper.getBlocksPageByhousingEstateId(page, blockListDto);
    }

    @Override
    public BlocksPreSaleTotalDto getPreSaleTotal(String landListId) {
        // 合计预售，合计去化
        BlocksPreSaleTotalDto saleInfo = baseMapper.getSaleInfo(landListId);
        if (saleInfo.getPreSaleTotal() > 0) {
            //计算去化率
            BigDecimal destroyTotal = new BigDecimal(saleInfo.getDestroyTotal());
            BigDecimal preSaleTotal = new BigDecimal(saleInfo.getPreSaleTotal());
            saleInfo.setDestroyTotalRate(destroyTotal.divide(preSaleTotal, 2, BigDecimal.ROUND_HALF_UP).multiply(new BigDecimal(100)).doubleValue());
        }

        // 住宅均价
        BigDecimal preSaleHousePrice = baseMapper.getHouseAvgPrice("住宅",landListId);
        //商业均价
        BigDecimal preSaleBusinessPrice = baseMapper.getHouseAvgPrice("商业",landListId);
        saleInfo.setPreSaleHousePrice(preSaleHousePrice.setScale(0, BigDecimal.ROUND_HALF_UP).intValue());
        saleInfo.setPreSaleBusinessPrice(preSaleBusinessPrice.setScale(0, BigDecimal.ROUND_HALF_UP).intValue());
        return saleInfo;
    }

    @Override
    public List<BlocksPreSaleTotalDto> getPreSaleDetailList(String landListedId, String buildingName) {
        //获取楼盘id
        List<AnnoBlocksRel> annoBlocksRelList = new ArrayList<>();
        //判断楼盘名称是不是空的
        if( StringUtils.isNotBlank(buildingName)){
            List<HousingEstates> housingEstates = housingEstatesMapper.selectList(Wrappers.<HousingEstates>query().lambda().eq(HousingEstates::getName, buildingName));
            if(housingEstates.size() == 1){
                annoBlocksRelList =  annoBlocksRelMapper.selectList(Wrappers.<AnnoBlocksRel>query().lambda()
                        .eq(AnnoBlocksRel::getLandListedId, landListedId)
                        .eq(AnnoBlocksRel::getMainLand, 1)
                        .eq(AnnoBlocksRel::getHousingEstatesId,housingEstates.get(0).getHousingEstateId())
                );
            }
        }else{
            annoBlocksRelList =  annoBlocksRelMapper.selectList(Wrappers.<AnnoBlocksRel>query().lambda()
                    .eq(AnnoBlocksRel::getLandListedId, landListedId)
                    .eq(AnnoBlocksRel::getMainLand, 1)
            );
        }
        if (annoBlocksRelList.size() != 1) {
            return null;
        }
        List<BlocksPreSaleTotalDto> saleTotalDtoList = baseMapper.getHouseSaleInfo(annoBlocksRelList.get(0).getHousingEstatesId());
        if (CollectionUtil.isNotEmpty(saleTotalDtoList)) {
            saleTotalDtoList.forEach(saleInfo -> {
                if (saleInfo.getPreSaleTotal() > 0) {
                    //计算去化率
                    BigDecimal destroyTotal = new BigDecimal(saleInfo.getDestroyTotal());
                    BigDecimal preSaleTotal = new BigDecimal(saleInfo.getPreSaleTotal());
                    saleInfo.setDestroyTotalRate(destroyTotal.divide(preSaleTotal, 2, BigDecimal.ROUND_HALF_UP).multiply(new BigDecimal(100)).doubleValue());
                }
            });
        }
        return saleTotalDtoList;
    }

    /**
     * 根据id查询业态信息
     * @param id
     * @return
     */
    @Override
    public BlocksVO selectCommercialActivities(Long id) {
        BlocksVO blocksVO = new BlocksVO();
        Blocks blocks = blocksMapper.selectById(id);
        HousingEstates housingEstates = housingEstatesMapper.selectById(blocks.getHousingEstateId());
        Format format = formatMapper.selectById(blocks.getFormatId());
        blocksVO.setBlockId(blocks.getBlockId());
        blocksVO.setBlockName(housingEstates.getName());
        blocksVO.setHousingEstateId(housingEstates.getHousingEstateId());
        blocksVO.setFormat(format.getFormat());
        blocksVO.setPropertyType(format.getPropertyType());
        blocksVO.setLargeFormat(format.getLargeFormat());
        blocksVO.setFormatId(format.getFormatId());
        return blocksVO;
    }

    /**
     * 修改信息
     * @param blocks
     * @return
     */
    @Override
    public int updateByIdBlocks(Blocks blocks) {
        log.info("+++++++++++++++++++{}",blocks);
        Format format = new Format();
        format.setHousingEstateId(blocks.getHousingEstateId());
        format.setFormat(blocks.getFormat());
        format.setPropertyType(blocks.getPropertyType());
        format.setLargeFormat(blocks.getLargeFormat());
        formatMapper.update(format,Wrappers.<Format>query().lambda()
                .eq(Format::getFormatId,blocks.getFormatId())
        );

        return blocksMapper.updateById(blocks);
    }
}
