package com.air.land.controller;

import cn.hutool.core.bean.BeanUtil;
import com.air.land.entity.AuctionRecord;
import com.air.land.service.AuctionRecordService;
import com.air.land.vo.AuctionRecordPageVo;
import com.air.land.vo.AuctionRecordVo;
import com.air.utils.ExcelUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.cinderella.framework.common.core.util.R;
import com.cinderella.framework.common.data.mybatis.QueryPage;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.List;


/**
 * 参拍记录表
 *
 * @author peihao
 * @date 2021-05-18 09:39:41
 */
@RestController
@AllArgsConstructor
@Validated
@RequestMapping("/auction_record")
@Api(value = "auction_record", tags = "参拍记录表管理")
public class AuctionRecordController {

    private final AuctionRecordService auctionRecordService;

    /**
     * 查询参拍记录列表
     *
     * @param recordPageVo 已挂牌地块标识
     * @return
     */
    @ApiOperation(value = "查询参拍记录列表", notes = "查询参拍记录列表")
    @GetMapping("/list")
    public R<IPage<AuctionRecord>> getAuctionRecordPage(QueryPage page, AuctionRecordPageVo recordPageVo) {
        IPage<AuctionRecord> recordPage = auctionRecordService.selectPage(page.toPage(),recordPageVo);
        return R.ok(recordPage, "查询成功");
    }

    /**
     * 保存参拍记录
     *
     * @param auctionRecordVo 保存参拍记录
     * @return R
     */
    @ApiOperation(value = "保存或更新参拍记录", notes = "保存参拍记录")
    @PostMapping
    public R<Boolean> save(@RequestBody @Validated AuctionRecordVo auctionRecordVo) {
        AuctionRecord auctionRecord = new AuctionRecord();
        BeanUtil.copyProperties(auctionRecordVo, auctionRecord);
        return R.ok(auctionRecordService.saveOrUpdate(auctionRecord));
    }

    @ApiOperation(value = "保存或更新参拍记录(多个)", notes = "保存参拍记录")
    @PostMapping("/multi")
    @Transactional(rollbackFor = Exception.class)
    public R<Boolean> saveBatch(@RequestBody @Valid List<AuctionRecordVo> auctionRecords) {
        auctionRecords.forEach(a -> {
            AuctionRecord auctionRecord = new AuctionRecord();
            BeanUtil.copyProperties(a, auctionRecord);
            auctionRecordService.saveOrUpdate(auctionRecord);
        });
        return R.ok();
    }

    /**
     * 通过id查询参拍记录表
     *
     * @param id
     * @return R
     */
    @ApiOperation(value = "通过id查询参拍记录表", notes = "通过id查询参拍记录表")
    @GetMapping("/{id}")
    public R getById(@PathVariable Long id) {
        return R.ok(auctionRecordService.getById(id));
    }

    /**
     * 通过id删除参拍记录表
     *
     * @param ids
     * @return R
     */
    @ApiOperation(value = "通过ids删除参拍记录表", notes = "通过ids删除参拍记录表")
    @DeleteMapping
    public R removeByIds(@RequestBody List<Long> ids) {
        return R.ok(auctionRecordService.removeByIds(ids));
    }

    /**
     * 导入已挂牌地块土拍举牌记录,返回数据，前端调接口保存
     * @author peihao
     * @date 2021/5/25
     **/
    @ApiOperation(value = "导入已挂牌地块土拍举牌记录", notes = "导入已挂牌地块土拍举牌记录")
    @PostMapping(value = "/importRecordExcel")
    public R<List<AuctionRecord>> importRecordExcel(@RequestParam(value="uploadFile") MultipartFile file){
        return R.ok(auctionRecordService.readRecordExcel(file));
    }

    /**
     * 导出地块参拍记录
     *
     * @author peihao
     * @date 2021/5/25
     **/
    @ApiOperation(value = "导出地块参拍记录", notes = "导出地块参拍记录")
    @GetMapping("/exportRecordExcel")
    public void exportLandListExcel(HttpServletResponse response, @RequestParam List<Long> auctionRecordIds) throws IOException {
        List<List<String>> recordList = auctionRecordService.getAuctionRecord(auctionRecordIds);
        InputStream resourceAsStream = LandListedController.class.getClassLoader().getResourceAsStream("templates/excel/auction_record.xlsx");
        // 读取excel模板
        XSSFWorkbook wb = ExcelUtil.exportLandListedExcel(recordList,resourceAsStream,1);
        response.setContentType("application/vnd.ms-excel;charset=utf-8");
        response.setHeader("Content-Disposition", "attachment;filename=report.xlsx");
        OutputStream outputStream = response.getOutputStream();
        wb.write(outputStream);
    }

}
