package com.air.land.controller;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.cinderella.framework.common.core.util.R;
import com.air.land.entity.LandListedConductEnterprise;
import com.air.land.service.LandListedConductEnterpriseService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.*;


/**
 * 已挂牌地块关联经营企业
 *
 * @author peihao
 * @date 2021-06-17 20:07:35
 */
@RestController
@AllArgsConstructor
@RequestMapping("/landlistedconductenterprise")
@Api(value = "landlistedconductenterprise", tags = "已挂牌地块关联经营企业管理")
public class LandListedConductEnterpriseController {

    private final  LandListedConductEnterpriseService landListedConductEnterpriseService;

    /**
     * 分页查询
     * @param page 分页对象
     * @param landListedConductEnterprise 已挂牌地块关联经营企业
     * @return
     */
    @ApiOperation(value = "分页查询", notes = "分页查询")
    @GetMapping("/page")
    public R getLandListedConductEnterprisePage(Page page, LandListedConductEnterprise landListedConductEnterprise) {
        return R.ok(landListedConductEnterpriseService.page(page, Wrappers.query(landListedConductEnterprise)));
    }


    /**
     * 通过id查询已挂牌地块关联经营企业
     * @param conductEnterpriseId id
     * @return R
     */
    @ApiOperation(value = "通过id查询", notes = "通过id查询")
    @GetMapping("/{conductEnterpriseId}")
    public R getById(@PathVariable("conductEnterpriseId") Long conductEnterpriseId) {
        return R.ok(landListedConductEnterpriseService.getById(conductEnterpriseId));
    }

    /**
     * 新增已挂牌地块关联经营企业
     * @param landListedConductEnterprise 已挂牌地块关联经营企业
     * @return R
     */
    @ApiOperation(value = "新增已挂牌地块关联经营企业", notes = "新增已挂牌地块关联经营企业")
    @PostMapping
    public R save(@RequestBody LandListedConductEnterprise landListedConductEnterprise) {
        return R.ok(landListedConductEnterpriseService.save(landListedConductEnterprise));
    }

    /**
     * 修改已挂牌地块关联经营企业
     * @param landListedConductEnterprise 已挂牌地块关联经营企业
     * @return R
     */
    @ApiOperation(value = "修改已挂牌地块关联经营企业", notes = "修改已挂牌地块关联经营企业")
    @PutMapping
    public R updateById(@RequestBody LandListedConductEnterprise landListedConductEnterprise) {
        return R.ok(landListedConductEnterpriseService.updateById(landListedConductEnterprise));
    }

    /**
     * 通过id删除已挂牌地块关联经营企业
     * @param conductEnterpriseId id
     * @return R
     */
    @ApiOperation(value = "通过id删除已挂牌地块关联经营企业", notes = "通过id删除已挂牌地块关联经营企业")
    @DeleteMapping("/{conductEnterpriseId}")
    public R removeById(@PathVariable Long conductEnterpriseId) {
        return R.ok(landListedConductEnterpriseService.removeById(conductEnterpriseId));
    }
}
