package com.air.land.controller;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.StrUtil;
import com.air.land.dto.LandListedStatisticsDto;
import com.air.land.entity.LandListedLonLat;
import com.air.land.service.LandListedLonLatService;
import com.air.land.vo.LandListedLonLatVo;
import com.air.utils.DateUtil;
import com.air.utils.WgsUtil;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.cinderella.framework.common.core.util.R;
import com.vividsolutions.jts.geom.Geometry;
import com.vividsolutions.jts.geom.Polygon;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.time.LocalDateTime;
import java.util.List;


/**
 * 已挂牌地块经纬度
 *
 * @author peihao
 * @date 2021-05-18 09:40:04
 */
@Slf4j
@RestController
@AllArgsConstructor
@RequestMapping("/landlistedlonlat")
@Api(value = "landlistedlonlat", tags = "已挂牌地块经纬度管理")
public class LandListedLonLatController {

    private final LandListedLonLatService landListedLonLatService;

    /**
     * 经纬度列表查询
     *
     * @return
     */
    @ApiOperation(value = "通过公告序号经纬度列表查询", notes = "通过公告序号经纬度列表查询")
    @GetMapping("/list/{landListedId}")
    public R<List<LandListedLonLat>> getLandListedLonLatPage(@PathVariable String landListedId) {
        List<LandListedLonLat> list = landListedLonLatService.list(Wrappers.<LandListedLonLat>query().lambda()
                .eq(LandListedLonLat::getLandListedId, landListedId)
                .orderByAsc(LandListedLonLat::getLatId));
        return R.ok(list, "查询成功");
    }

    /**
     * 新增已挂牌地块经纬度
     *
     * @param landListedLonLatVo 新增已挂牌地块经纬度
     * @return R
     */
    @ApiOperation(value = "新增已挂牌地块经纬度", notes = "新增已挂牌地块经纬度")
    @PostMapping
    public R save(@RequestBody @Validated LandListedLonLatVo landListedLonLatVo) {
        LandListedLonLat landListedLonLat = new LandListedLonLat();
        BeanUtil.copyProperties(landListedLonLatVo, landListedLonLat);
        String landLonLat = landListedLonLat.getLandLonLat();
        if(StrUtil.isNotEmpty(landLonLat)){
            String[] split = landLonLat.split(";");
            landListedLonLat.setLandLonLat(new StringBuffer(landLonLat).append(";").append(split[0]).toString());
        }
        //转换经纬度标准格式
        landListedLonLat.setLandLonLat(WgsUtil.wgs84_To_Gcj02(landListedLonLat.getLandLonLat()));
        return R.ok(landListedLonLatService.save(landListedLonLat), "保存成功");
    }

    /**
     * 修改拟挂牌地块经纬度
     *
     * @param landListedLonLatVo 修改拟挂牌地块经纬度
     * @return R
     */
    @ApiOperation(value = "修改拟挂牌地块经纬度", notes = "修改拟挂牌地块经纬度")
    @PutMapping
    public R update(@RequestBody @Validated LandListedLonLatVo landListedLonLatVo) {
        if (landListedLonLatVo.getLatId() == null){
            return R.failed("经纬度id不能为空");
        }
        log.info("参数==="+landListedLonLatVo);
        LandListedLonLat landListedLonLat = new LandListedLonLat();
        BeanUtil.copyProperties(landListedLonLatVo, landListedLonLat);
        //转换经纬度标准格式
        //landListedLonLat.setLandLonLat(null);
        landListedLonLatService.update(landListedLonLat, Wrappers.<LandListedLonLat>query().lambda()
                .eq(LandListedLonLat::getLatId, landListedLonLatVo.getLatId()));
        return R.ok("修改成功");
    }

    /**
     * 通过id删除已挂牌地块经纬度
     *
     * @param latId id
     * @return R
     */
    @ApiOperation(value = "通过id删除已挂牌地块经纬度", notes = "通过id删除已挂牌地块经纬度")
    @DeleteMapping("/{latId}")
    public R removeById(@PathVariable Long latId) {
        boolean remove = landListedLonLatService.removeById(latId);
        return R.ok(remove);
    }


    /**
     * 导入已挂牌地块经纬度数据
     * @author peihao
     * @date 2021/5/25
     **/
    @ApiOperation(value = "导入已挂牌地块经纬度数据", notes = "导入已挂牌地块经纬度数据")
    @PostMapping(value = "/importLandListLatExcel")
    public R importLandListLatExcel(@RequestParam(value="uploadFile") MultipartFile file,String landListedId){
        return R.ok(landListedLonLatService.importLandListedLonLatExcel(file,landListedId));
    }

    /**
     * 经纬度转换（wgs84_To_Gcj02）
     * @return R
     */
    @ApiOperation(value = "经纬度转换（wgs84_To_Gcj02）", notes = "经纬度转换（wgs84_To_Gcj02）")
    @GetMapping("/landListLonLatConversion")
    public R<Boolean> landListLonLatConversion() {
        List<LandListedLonLat> list = landListedLonLatService.list();
        if (CollectionUtil.isNotEmpty(list)){
            list.forEach(landListedLonLat -> {
                if(StrUtil.isNotEmpty(landListedLonLat.getLandLonLat())){
                    try{
                        String[] split = landListedLonLat.getLandLonLat().split(";");
                        String lonlat = new StringBuffer(landListedLonLat.getLandLonLat()).append(";").append(split[0]).toString();
                        landListedLonLat.setLandLonLat(lonlat);
                    }catch (Exception e){
                        log.error(landListedLonLat.getLandListedId()+"已挂牌经纬度转换出错!",e);
                    }
                }
            });
        }
        return R.ok(landListedLonLatService.saveBatch(list));
    }

}
