package com.air.land.controller;

import com.air.land.entity.LandToListAttachment;
import com.air.land.service.LandToListAttachmentService;
import com.air.utils.FileUtil;
import com.air.utils.ValidList;
import com.cinderella.framework.common.core.util.R;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;


/**
 * 拟挂牌地块文件信息
 *
 * @author peihao
 * @date 2021-05-18 09:39:41
 */
@RestController
@AllArgsConstructor
@RequestMapping("/landToListAttachment")
@Api(value = "landToListAttachment", tags = "拟挂牌地块文件信息管理")
public class LandToListAttachmentController {

    private final LandToListAttachmentService attachmentService;

    private final FileUtil fileUtil;

    /**
     * 通过序号和文件类型查询文件列表
     *
     * @param proposedseriaId 拟公告序号
     * @param fileType        文件类型
     * @return
     */
    @ApiOperation(value = "通过序号和文件类型查询文件列表", notes = "通过序号和文件类型查询文件列表")
    @GetMapping
    public R<List<LandToListAttachment>> getListToListAttachment(@RequestParam String proposedseriaId, String fileType) {
        return attachmentService.getListAttachment(proposedseriaId, fileType);
    }

    /**
     * 保存地块文件
     *
     * @param attachments 文件参数
     * @return R
     */
    @ApiOperation(value = "保存地块文件", notes = "保存地块文件")
    @PostMapping
    public R<Boolean> saveAttachment(@RequestBody @Validated ValidList<LandToListAttachment> attachments) {
        attachments.forEach(attachment ->{
            attachment.setFilePath(fileUtil.getInnerPath(attachment.getFilePath()));
        });
        return R.ok(attachmentService.saveOrUpdateBatch(attachments));
    }

    /**
     * 通过id删除地块文件
     *
     * @param id
     * @return R
     */
    @ApiOperation(value = "通过id删除地块文件", notes = "通过id删除地块文件")
    @DeleteMapping("/{id}")
    public R removeById(@PathVariable Long id) {
        return R.ok(attachmentService.removeById(id));
    }
}
