package com.air.land.controller;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.cinderella.framework.common.core.util.R;
import com.air.land.entity.LandToListConstructionPlan;
import com.air.land.service.LandToListConstructionPlanService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.*;


/**
 * 拟挂牌地块关联建设规划
 *
 * @author peihao
 * @date 2021-06-17 20:07:50
 */
@RestController
@AllArgsConstructor
@RequestMapping("/landtolistconstructionplan")
@Api(value = "landtolistconstructionplan", tags = "拟挂牌地块关联建设规划管理")
public class LandToListConstructionPlanController {

    private final  LandToListConstructionPlanService landToListConstructionPlanService;

    /**
     * 分页查询
     * @param page 分页对象
     * @param landToListConstructionPlan 拟挂牌地块关联建设规划
     * @return
     */
    @ApiOperation(value = "分页查询", notes = "分页查询")
    @GetMapping("/page")
    public R getLandToListConstructionPlanPage(Page page, LandToListConstructionPlan landToListConstructionPlan) {
        return R.ok(landToListConstructionPlanService.page(page, Wrappers.query(landToListConstructionPlan)));
    }


    /**
     * 通过id查询拟挂牌地块关联建设规划
     * @param constructionPlanId id
     * @return R
     */
    @ApiOperation(value = "通过id查询", notes = "通过id查询")
    @GetMapping("/{constructionPlanId}")
    public R getById(@PathVariable("constructionPlanId") Long constructionPlanId) {
        return R.ok(landToListConstructionPlanService.getById(constructionPlanId));
    }

    /**
     * 新增拟挂牌地块关联建设规划
     * @param landToListConstructionPlan 拟挂牌地块关联建设规划
     * @return R
     */
    @ApiOperation(value = "新增拟挂牌地块关联建设规划", notes = "新增拟挂牌地块关联建设规划")
    @PostMapping
    public R save(@RequestBody LandToListConstructionPlan landToListConstructionPlan) {
        return R.ok(landToListConstructionPlanService.save(landToListConstructionPlan));
    }

    /**
     * 修改拟挂牌地块关联建设规划
     * @param landToListConstructionPlan 拟挂牌地块关联建设规划
     * @return R
     */
    @ApiOperation(value = "修改拟挂牌地块关联建设规划", notes = "修改拟挂牌地块关联建设规划")
    @PutMapping
    public R updateById(@RequestBody LandToListConstructionPlan landToListConstructionPlan) {
        return R.ok(landToListConstructionPlanService.updateById(landToListConstructionPlan));
    }

    /**
     * 通过id删除拟挂牌地块关联建设规划
     * @param constructionPlanId id
     * @return R
     */
    @ApiOperation(value = "通过id删除拟挂牌地块关联建设规划", notes = "通过id删除拟挂牌地块关联建设规划")
    @DeleteMapping("/{constructionPlanId}")
    public R removeById(@PathVariable Long constructionPlanId) {
        return R.ok(landToListConstructionPlanService.removeById(constructionPlanId));
    }
}
