package com.air.land.controller;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.StrUtil;
import com.air.land.entity.LandListedLonLat;
import com.air.land.entity.LandToListLonLat;
import com.air.land.service.LandToListLonLatService;
import com.air.land.vo.LandToListLonLatVo;
import com.air.utils.WgsUtil;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.cinderella.framework.common.core.util.R;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;


/**
 * 拟挂牌地块经纬度
 *
 * @author peihao
 * @date 2021-05-18 09:40:15
 */
@Slf4j
@RestController
@AllArgsConstructor
@RequestMapping("/landtolistlonlat")
@Api(value = "landtolistlonlat", tags = "拟挂牌地块经纬度管理")
public class LandToListLonLatController {

    private final LandToListLonLatService landToListLonLatService;

    /**
     * 通过拟公告序号经纬度列表查询
     *
     * @return
     */
    @ApiOperation(value = "通过拟公告序号经纬度列表查询", notes = "通过拟公告序号经纬度列表查询")
    @GetMapping("/list/{proposedseriaId}")
    public R<List<LandToListLonLat>> getLandListedLonLatPage(@PathVariable String proposedseriaId) {
        List<LandToListLonLat> list = landToListLonLatService.list(Wrappers.<LandToListLonLat>query().lambda()
                .eq(LandToListLonLat::getProposedseriaId, proposedseriaId)
                .orderByAsc(LandToListLonLat::getLatId));
        return R.ok(list, "查询成功");
    }

    /**
     * 新增拟挂牌地块经纬度
     *
     * @param landToListLonLatVo 新增拟挂牌地块经纬度
     * @return R
     */
    @ApiOperation(value = "新增拟挂牌地块经纬度", notes = "新增拟挂牌地块经纬度")
    @PostMapping
    public R<Boolean> save(@RequestBody @Validated LandToListLonLatVo landToListLonLatVo) {
        List<LandToListLonLat> list = landToListLonLatService.list(Wrappers.<LandToListLonLat>query().lambda()
                .eq(LandToListLonLat::getProposedseriaId, landToListLonLatVo.getProposedseriaId())
                .eq(LandToListLonLat::getLandCode, landToListLonLatVo.getLandCode()));
        if (CollectionUtil.isNotEmpty(list)) {
            return R.failed("地块编号已存在");
        }
        LandToListLonLat landToListLonLat = new LandToListLonLat();
        BeanUtil.copyProperties(landToListLonLatVo, landToListLonLat);
        String landLonLat = landToListLonLat.getLandLonLat();
        if (StrUtil.isNotEmpty(landLonLat)) {
            String[] split = landLonLat.split(";");
            landToListLonLat.setLandLonLat(new StringBuffer(landLonLat).append(";").append(split[0]).toString());
        }
        //转换经纬度标准格式
        landToListLonLat.setLandLonLat(WgsUtil.wgs84_To_Gcj02(landToListLonLat.getLandLonLat()));
        return R.ok(landToListLonLatService.save(landToListLonLat), "保存成功");
    }

    /**
     * 修改拟挂牌地块经纬度
     *
     * @param landToListLonLatVo 修改拟挂牌地块经纬度
     * @return R
     */
    @ApiOperation(value = "修改拟挂牌地块经纬度", notes = "修改拟挂牌地块经纬度")
    @PutMapping
    public R update(@RequestBody @Validated LandToListLonLatVo landToListLonLatVo) {
        LandToListLonLat landToListLonLat = new LandToListLonLat();
        BeanUtil.copyProperties(landToListLonLatVo, landToListLonLat);
        //转换经纬度标准格式
        landToListLonLat.setLandLonLat(null);
        landToListLonLatService.update(landToListLonLat, Wrappers.<LandToListLonLat>query().lambda()
                .eq(LandToListLonLat::getLatId, landToListLonLatVo.getLatId()));
        return R.ok("修改成功");
    }

    /**
     * 通过拟公告序号和地块编号删除拟挂牌地块经纬度
     * 地块编号
     *
     * @return R
     */
    @ApiOperation(value = "通过拟公告序号和地块编号删除", notes = "通过拟公告序号和地块编号删除")
    @DeleteMapping("/{latId}")
    public R removeById(@PathVariable String latId) {
        boolean remove = landToListLonLatService.removeById(latId);
        return R.ok(remove);
    }

    /**
     * 导入拟挂牌地块经纬度数据
     *
     * @author peihao
     * @date 2021/5/25
     **/
    @ApiOperation(value = "导入拟挂牌地块经纬度数据", notes = "导入拟挂牌地块经纬度数据")
    @PostMapping(value = "/importLandToListLatExcel")
    public R importLandToListLatExcel(@RequestParam(value = "uploadFile") MultipartFile file,@RequestParam String proposedseriaId) {
        return R.ok(landToListLonLatService.importLandToListedLonLatExcel(file,proposedseriaId));
    }

    /**
     * 经纬度转换（wgs84_To_Gcj02）
     * @return R
     */
    @ApiOperation(value = "经纬度转换（wgs84_To_Gcj02）", notes = "经纬度转换（wgs84_To_Gcj02）")
    @GetMapping("/landToListLonLatConversion")
    public R<Boolean> landToListLonLatConversion() {
        List<LandToListLonLat> list = landToListLonLatService.list();
        if (CollectionUtil.isNotEmpty(list)){
            list.forEach(landToListLonLat -> {
                if(StrUtil.isNotEmpty(landToListLonLat.getLandLonLat())){
                    try{
                        String[] split = landToListLonLat.getLandLonLat().split(";");
                        landToListLonLat.setLandLonLat(new StringBuffer(landToListLonLat.getLandLonLat()).append(";").append(split[0]).toString());
                    }catch (Exception e){
                        log.error(landToListLonLat.getProposedseriaId()+"拟挂牌经纬度转换出错!",e);
                    }
                }
            });
        }
        return R.ok(landToListLonLatService.saveBatch(list));
    }

}
