package com.air.land.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.lang.Snowflake;
import cn.hutool.core.util.StrUtil;
import com.air.applets.dto.LandDto;
import com.air.applets.vo.LandVo;
import com.air.land.controller.LandListedController;
import com.air.land.dto.LandListedDto;
import com.air.land.dto.LandListedStatisticsDto;
import com.air.land.entity.*;
import com.air.land.mapper.LandListedMapper;
import com.air.land.service.*;
import com.air.land.vo.LandListedAppletsVo;
import com.air.utils.DateUtil;
import com.air.utils.ExcelUtil;
import com.air.utils.RedisUtil;
import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.enums.SqlMethod;
import com.baomidou.mybatisplus.core.toolkit.BeanUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cinderella.framework.common.core.exception.BusinessException;
import com.cinderella.framework.common.core.util.R;
import com.cinderella.framework.common.data.mybatis.QueryPage;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.apache.poi.xssf.usermodel.XSSFCell;
import org.apache.poi.xssf.usermodel.XSSFRow;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.scheduling.annotation.Async;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.concurrent.TimeUnit;
import java.util.stream.Collectors;

/**
 * 已挂牌地块，整体数据的核心，数据来源三部分：爬虫数据、用户维护数据、系统计算数据。
 *
 * @author peihao
 * @date 2021-05-18 09:39:59
 */
@Slf4j
@Service
@AllArgsConstructor
public class LandListedServiceImpl extends ServiceImpl<LandListedMapper, LandListed> implements LandListedService {

    private LandListedLonLatService listedLonLatService;

    private LandListedConductEnterpriseService conductEnterpriseService;

    private LandListedConstructionPlanService constructionPlanService;

    private LandAttachmentService attachmentService;

    private AuctionRecordService auctionRecordService;

    @Autowired
    private RedisUtil redisUtil;

    @Override
    public R<Page<LandListedDto>> getLandListedByDate(QueryPage page, LandListedAppletsVo appletsVo) {
        Page<LandListedDto> page1 = page.toPage();
        List<LandListedDto> landListedByDate = baseMapper.getLandListedByDate(page1, appletsVo);
        return R.ok(page1.setRecords(landListedByDate));
    }

    @Override
    public R<LandListedStatisticsDto> appletsStatistics(LandListedAppletsVo appletsVo) {
        appletsVo.setAnnoDate(appletsVo.getDate());
        appletsVo.setAuctionDate(null);
        Integer listedCount = baseMapper.statisticsListedCount(appletsVo);
        appletsVo.setAuctionDate(appletsVo.getDate());
        appletsVo.setAnnoDate(null);
        Integer auctionCount = baseMapper.statisticsListedCount(appletsVo);
        LandListedStatisticsDto statisticsDto = new LandListedStatisticsDto();
        statisticsDto.setDate(appletsVo.getDate());
        statisticsDto.setListedCount(listedCount);
        statisticsDto.setAuctionCount(auctionCount);
        return R.ok(statisticsDto, "查询成功");
    }

    @Override
    public R<List<LandListedStatisticsDto>> appletsCalendar(String date, String city, String canton) {
        List<LandListedStatisticsDto> annoDateList = baseMapper.appletsCalendarToAnnoDate(date, city, canton);//按挂牌日期统计地块数量(日历)
        List<LandListedStatisticsDto> auctionDateList = baseMapper.appletsCalendarToAuctionDate(date, city, canton);//按拍卖日期统计地块数量(日历)
        if (CollectionUtil.isEmpty(annoDateList)) {
            return R.ok(auctionDateList);
        }
        if (CollectionUtil.isEmpty(auctionDateList)) {
            return R.ok(annoDateList);
        }
        List<LandListedStatisticsDto> indexs = new ArrayList<>();
        for (LandListedStatisticsDto annoDateVo : annoDateList) {
            for (int i = 0; i < auctionDateList.size(); i++) {
                if (annoDateVo.getDate().equals(auctionDateList.get(i).getDate())) {
                    annoDateVo.setAuctionCount(auctionDateList.get(i).getAuctionCount());
                    indexs.add(auctionDateList.get(i));
                }
            }
        }
        auctionDateList.removeAll(indexs);
        if (CollectionUtil.isNotEmpty(auctionDateList)) {
            annoDateList.addAll(auctionDateList);
        }
        return R.ok(annoDateList);
    }

    @Override
    public boolean importLandListExcel(MultipartFile file) {
        List<LandListed> dataList;
        try {
            dataList = ExcelUtil.importExcel(file.getInputStream(), 0, 1, 0, LandListed.class, "config/landListed-config.json");
        } catch (Exception e) {
            e.printStackTrace();
            log.error("导入已挂牌地块数据出错", e);
            throw new BusinessException(e.getMessage());
        }
        dataList=dataList.stream().filter(x->{
            return StringUtils.isNotEmpty( x.getAnnoId());
        }).collect(Collectors.toList());
        if (CollectionUtil.isNotEmpty(dataList)) {
            try {
                dataList.forEach(landListed -> {
                    if(StringUtils.isEmpty(landListed.getLandListedId())) landListed.setLandListedId(DateUtil.landListedIdfromDate(LocalDateTime.now(), "yyyyMMdd", this.selectId()));
                    //土地出让面积，计算土地出让面积（亩）（出让面积/2000*3）
                    BigDecimal landTransferSquare = landListed.getLandTransferSquare();
                    if (landTransferSquare != null) {
                        landListed.setLandTransferMu(landTransferSquare.divide(new BigDecimal(2000), 4, BigDecimal.ROUND_HALF_UP).multiply(new BigDecimal(3)).setScale(0, BigDecimal.ROUND_HALF_UP));
                    }
                    //总建筑面积
                    BigDecimal totalConsArea = landListed.getTotalConsArea();
                    //成交价(万元)
                    BigDecimal dealPrice = null;
                    //出让价款起始价（万元）
                    BigDecimal transferPrice = null;
                    if (totalConsArea != null) {
                        //计算容积率(总建筑面积/土地出让面积)
                        if (landTransferSquare != null) {
                            landListed.setPlotRatio(totalConsArea.doubleValue() == 0 ? new BigDecimal(0) : totalConsArea.divide(landTransferSquare, 2, BigDecimal.ROUND_HALF_UP));
                        }
                        //出让价款起始价（万元），计算起始楼面价(元/㎡) （出让价款起始价/总建筑面积*10000）
                        transferPrice = landListed.getTransferPrice();
                        if (transferPrice != null) {
                            landListed.setStartingFloorPrice((transferPrice.doubleValue() == 0 || totalConsArea.doubleValue() == 0)
                                    ? new BigDecimal(0) : transferPrice.divide(totalConsArea, 4, BigDecimal.ROUND_HALF_UP)
                                    .multiply(new BigDecimal(10000)).setScale(0, BigDecimal.ROUND_HALF_UP));
                        }
                        //商业面积，商务面积
                        BigDecimal bizSpace = landListed.getBizSpace() == null ? new BigDecimal(0) : landListed.getBizSpace();
                        BigDecimal commerceSpace = landListed.getCommerceSpace() == null ? new BigDecimal(0) : landListed.getCommerceSpace();
                        //计算商业商务占比（（商业面积+商务面积）/总建筑面积）
                        landListed.setBizCommerceRate(totalConsArea.doubleValue() == 0 ? new BigDecimal(0) : (bizSpace.add(commerceSpace)).
                                divide(totalConsArea, 4, BigDecimal.ROUND_HALF_UP).multiply(new BigDecimal(100)).setScale(2, BigDecimal.ROUND_HALF_UP));
                        //成交价(万元),计算成交楼面价(元/㎡) （成交价/总建筑面积*10000）
                        dealPrice = landListed.getDealPrice();
                        if (dealPrice != null) {
                            landListed.setDealFloorPrice((dealPrice.doubleValue() == 0 || totalConsArea.doubleValue() == 0)
                                    ? new BigDecimal(0) : dealPrice.divide(totalConsArea, 4, BigDecimal.ROUND_HALF_UP)
                                    .multiply(new BigDecimal(10000)).setScale(0, BigDecimal.ROUND_HALF_UP));
                        }
                    }
                    //计算溢价率
                    if (dealPrice != null && transferPrice != null) {
                        landListed.setPremiumRate((dealPrice.doubleValue() == 0 || transferPrice.doubleValue() == 0)
                                ? new BigDecimal(0) : (dealPrice.subtract(transferPrice)).divide(transferPrice, 4, BigDecimal.ROUND_HALF_UP)
                                .multiply(new BigDecimal(100)).setScale(2, BigDecimal.ROUND_HALF_UP));
                    }

                });
            } catch (Exception e) {
                log.error("数据计算出错:",e);
            }
        }


        return this.saveOrUpdateBatch(dataList);
    }

    @Override
    public List<List<String>> getLandList(List<String> ids) {
        List<LandListed> landListeds=null;
        List<List<String>> lists = new ArrayList<>();
        if(ids==null){
            if(redisUtil.getCacheObject("/exportAllLandListExcel") != null){
                log.info("缓存取值！！！！！！！！！！！！！！！");
                lists =   redisUtil.getCacheObject("/exportAllLandListExcel");
                return lists;
            }else{
                landListeds = list();
                log.info("第一次取值取值！！！！！！！！！！！！！！！");

            }
        }else{
            landListeds = this.listByIds(ids);
        }
        if (CollectionUtil.isEmpty(landListeds)) {
            throw new BusinessException("未查询到已挂牌地块数据！");
        }
        List<List<String>> list = new ArrayList<>();
        landListeds.forEach(landListed -> {
            list.add(entityToList(landListed));
        });
        redisUtil.setCacheObject("/exportAllLandListExcel",list,63, TimeUnit.MINUTES);
        return list;
    }

    /**
     * 通过地区查询已挂牌地块数据
     * @param city 地区导出全部数据
     * @return
     */
    @Override
    public List<List<String>> getLandListCity(String city) {
        List<LandListed> landListeds=list(Wrappers.<LandListed>query().lambda()
                .eq(StringUtils.isNotBlank(city),LandListed :: getCity,city)
        );
        if(landListeds.size() > 0){
            List<List<String>> list = new ArrayList<>();
            landListeds.forEach(landListed -> {
                list.add(entityToList(landListed));
            });
            return list;
        }
       return null;
    }

    /**
     * 定时查询已挂出导出全部数据
     */
    @Async
   // @Scheduled(cron = "0 0/58 * * * *") // 10分执行一次 “0 0 12 ?” 每天12时执行一次
    public void selectCollection() throws IOException {
        log.info("定时查询已挂出导出全部数据"+System.currentTimeMillis());
        List<LandListed>   landListeds = list();
        if (!CollectionUtil.isEmpty(landListeds)) {
            List<List<String>> list = new ArrayList<>();
            landListeds.forEach(landListed -> {
                list.add(entityToList(landListed));
            });
            redisUtil.setCacheObject("/exportAllLandListExcel",list,63, TimeUnit.MINUTES);//全部数据类型

//            InputStream resourceAsStream = LandListedController.class.getClassLoader().getResourceAsStream("templates/excel/exportLandList.xlsx");
//            // 读取excel模板
//            XSSFWorkbook wb = ExcelUtil.exportLandListedExcel(list, resourceAsStream, 2);
//            redisUtil.setCacheObject("/exportAllLandListExcel/wb",wb,10, TimeUnit.MINUTES);
//            log.info("定时查询已挂出导出全部数据结束"+System.currentTimeMillis());
        }
    }

    @Override
    public List<LandDto> appletsLandListed(Page page, LandVo landVo) {
        landVo.setNowDate(cn.hutool.core.date.DateUtil.formatDate(new Date()));
        log.info("时间"+cn.hutool.core.date.DateUtil.formatDate(new Date()));
        List<LandDto> landDtos = baseMapper.appletsLandListed(page, landVo);
        if (StringUtils.isEmpty(landVo.getTransactionStatus())) {
            landDtos.forEach(landDto -> {
                landDto.setIsToBeListed("0");
            });
        } else {
            landDtos.forEach(landDto -> {
                landDto.setIsToBeListed("0");
                landDto.setTransactionStatus(landVo.getTransactionStatus());
            });
        }

        return landDtos;
    }

    @Override
    public Integer selectId() {
        return baseMapper.selectId();
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean removeLandByIds(List<String> landListedIds) {
        this.removeByIds(landListedIds);
        listedLonLatService.remove(Wrappers.<LandListedLonLat>query().lambda().in(LandListedLonLat::getLandListedId, landListedIds));
        conductEnterpriseService.remove(Wrappers.<LandListedConductEnterprise>query().lambda()
                .in(LandListedConductEnterprise::getLandListedId, landListedIds));
        constructionPlanService.remove(Wrappers.<LandListedConstructionPlan>query().lambda()
                .in(LandListedConstructionPlan::getLandListedId, landListedIds));
        auctionRecordService.remove(Wrappers.<AuctionRecord>query().lambda().in(AuctionRecord::getLandListedId, landListedIds));
        attachmentService.remove(Wrappers.<LandAttachment>query().lambda().in(LandAttachment::getLandListedId, landListedIds));
        return true;
    }

    /**
     * 导入地块数据
     *
     * @param file 导入文件
     * @return
     * @author peihao
     * @date 2021/6/17
     **/
    public List<LandListed> importLandListedExcel(MultipartFile file) throws IOException {
        // 读取excel模板
        XSSFWorkbook wb = new XSSFWorkbook(file.getInputStream());
        XSSFSheet sheet = wb.getSheetAt(0);
        int rowSum = sheet.getPhysicalNumberOfRows();
        //获取数据
        List<LandListed> result = new ArrayList<>();
        for (int i = 2; i < rowSum; i++) {
            XSSFRow sheetRow = sheet.getRow(i);
            LandListed landListed = new LandListed();
            landListed.setLandListedId(DateUtil.landListedIdfromDate(LocalDateTime.now(), "yyyyMMdd", this.selectId()));
            //公告信息
            landListed.setAnnoId(getAnnoId(sheetRow.getCell(0)));
            log.info("公告序号为： {}", landListed.getAnnoId());
            landListed.setLandCode(getCellStrValue(sheetRow.getCell(1)));
            landListed.setLandPosition(getCellStrValue(sheetRow.getCell(2)));
            landListed.setLandUsage(getCellStrValue(sheetRow.getCell(3)));
            landListed.setLandTransferSquare(numberFormat(getCellValue(sheetRow.getCell(4)), 0));
            landListed.setLandTransferMu(numberFormat(getCellValue(sheetRow.getCell(5)), 0));
            landListed.setTotalConsArea(numberFormat(getCellValue(sheetRow.getCell(6)), 0));
            landListed.setPlotRatio(numberFormat(getCellValue(sheetRow.getCell(7)), 2));
            landListed.setBuildingDensity((getCellStrValue(sheetRow.getCell(8))));
            landListed.setGreenSpaceRatio((getCellStrValue(sheetRow.getCell(9))));
            landListed.setHeighPermitted(getCellStrValue(sheetRow.getCell(10)));
            landListed.setRemiseYears(getCellStrValue(sheetRow.getCell(11)));
            landListed.setTransferPrice(numberFormat(getCellStrValue(sheetRow.getCell(12)), 0));
            landListed.setStartingFloorPrice(numberFormat(getCellValue(sheetRow.getCell(13)), 0));
            landListed.setBidMargin(numberFormat(getCellStrValue(sheetRow.getCell(14)), 0));
            landListed.setBizRemark(getCellStrValue(sheetRow.getCell(15)));
            try {
                landListed.setAnnoDate(DateUtil.dateToLocalDate(sheetRow.getCell(16).getDateCellValue()));
            } catch (Exception e) {
                log.error("公告开始日期转换出错", e);
            }
            try {
                landListed.setAnnoEndDate(DateUtil.dateToLocalDate(sheetRow.getCell(17).getDateCellValue()));
            } catch (Exception e) {
                log.error("公告截止日期转换出错", e);
            }
            try {
                landListed.setAuctionDate(DateUtil.dateToLocalDate(sheetRow.getCell(18).getDateCellValue()));
            } catch (Exception e) {
                log.error("拍卖日期转换出错", e);
            }
            landListed.setLicensedArea(numberFormat(getCellStrValue(sheetRow.getCell(19)), 0));
            //规划条件
            landListed.setBizSpace(numberFormat(getCellStrValue(sheetRow.getCell(20)), 0));
            landListed.setCommerceSpace(numberFormat(getCellStrValue(sheetRow.getCell(21)), 0));
            landListed.setBizCommerceRate(numberFormat(getCellValue(sheetRow.getCell(22)), 100, 2));
            landListed.setAllocationCapacity(getCellStrValue(sheetRow.getCell(23)));
            landListed.setAllocationNotCapacity(getCellStrValue(sheetRow.getCell(24)));
            //建设条件
            landListed.setGeologicHazard(getCellStrValue(sheetRow.getCell(25)));
            landListed.setCivilAirDefence((getCellStrValue(sheetRow.getCell(26))));
            landListed.setSpecialPlan(getCellStrValue(sheetRow.getCell(27)));
            landListed.setAssemblyBuilding(getCellStrValue(sheetRow.getCell(28)));
            landListed.setGreenBuilding(getCellStrValue(sheetRow.getCell(29)));
            landListed.setOtherConditions(getCellStrValue(sheetRow.getCell(30)));
            landListed.setPercentFinishedHousing(numberFormat(getCellStrValue(sheetRow.getCell(31)), 0));
            //竞买条件
            landListed.setBiddingConditions(getCellStrValue(sheetRow.getCell(32)));
            landListed.setHookForm(getCellStrValue(sheetRow.getCell(33)));
            landListed.setFirstGovernance(getCellStrValue(sheetRow.getCell(34)));
            landListed.setLandEnterprises(getCellStrValue(sheetRow.getCell(35)));
            landListed.setPaymentRhythm(getCellStrValue(sheetRow.getCell(36)));
            landListed.setBargainor(getCellStrValue(sheetRow.getCell(37)));
            //地理信息
            landListed.setCity(getCellStrValue(sheetRow.getCell(38)));
            landListed.setCanton(getCellStrValue(sheetRow.getCell(39)));
            landListed.setSpecialZone(getCellStrValue(sheetRow.getCell(40)));
            landListed.setLoopWire(getCellStrValue(sheetRow.getCell(41)));
            landListed.setBigGroup(getCellStrValue(sheetRow.getCell(42)));
            landListed.setSmallGroup(getCellStrValue(sheetRow.getCell(43)));
            landListed.setOvePosition(getCellStrValue(sheetRow.getCell(44)));
            landListed.setLonLatBd(getCellStrValue(sheetRow.getCell(45)));
            //成交信息
            if ("是".equals(getCellStrValue(sheetRow.getCell(46)))) {
                landListed.setDeal("1");
            } else if ("否".equals(getCellStrValue(sheetRow.getCell(46)))) {
                landListed.setDeal("0");
            }
            landListed.setTransferMode(getCellStrValue(sheetRow.getCell(47)));
            landListed.setAssignee(getCellStrValue(sheetRow.getCell(48)));
            landListed.setLandEnterpriseShort(getCellStrValue(sheetRow.getCell(49)));
            landListed.setDealPrice(numberFormat(getCellStrValue(sheetRow.getCell(50)), 0));
            landListed.setDealFloorPrice(numberFormat(getCellValue(sheetRow.getCell(51)), 0));
            landListed.setPremiumRate(numberFormat(getCellValue(sheetRow.getCell(52)), 100, 2));
            landListed.setCommercialSelfRatio(numberFormat(getCellStrValue(sheetRow.getCell(53)), 100, 0));
            String year = getCellStrValue(sheetRow.getCell(54));
            landListed.setCommercialSelfYear( year);
            landListed.setHomeSelfRatio((getCellStrValue(sheetRow.getCell(55))));
            year = (getCellStrValue(sheetRow.getCell(56)));
            landListed.setHomeSelfYear(year);
            landListed.setPercentUnpaid(numberFormat(getCellStrValue(sheetRow.getCell(57)), 2));
            landListed.setTalenApartmentArea(numberFormat(getCellStrValue(sheetRow.getCell(58)), 2));
            landListed.setParticipatingEnterprises(getCellStrValue(sheetRow.getCell(59)));
            //项目开发
            landListed.setProjectStatus(getCellStrValue(sheetRow.getCell(60)));
            landListed.setBuildingName(getCellStrValue(sheetRow.getCell(61)));
            landListed.setProjectCompany(getCellStrValue(sheetRow.getCell(62)));
            try {
                landListed.setConfirmationTime(DateUtil.dateToLocalDate(sheetRow.getCell(63).getDateCellValue()));
            } catch (Exception e) {
                log.error("确权时间转换出错", e);
            }
            landListed.setTradingEnterprises(getCellStrValue(sheetRow.getCell(64)));
            landListed.setPartner(getCellStrValue(sheetRow.getCell(65)));
            landListed.setConductEnterprise(getCellValue(sheetRow.getCell(66)));
            try {
                landListed.setFirstOpenTime(DateUtil.dateToLocalDate(sheetRow.getCell(67).getDateCellValue()));
            } catch (Exception e) {
                log.error("项目首开时间转换出错", e);
            }
            result.add(landListed);
        }
        return result;
    }

    /**
     * 将已挂牌地块信息转换为excel导出格式
     *
     * @param data 拟已牌地块信息
     * @return
     * @author peihao
     * @date 2021/8/25
     **/
    private List<String> entityToList(LandListed data) {
        List<String> list = new ArrayList<>();
        //公告信息
        list.add(data.getSystemId().toString());
        list.add(data.getLandListedId());

        list.add(data.getAnnoId());
        list.add(data.getLandCode());
        list.add(data.getLandPosition());
        list.add(data.getLandUsage());
        list.add(stringFormat(data.getLandTransferSquare(), 0));
        list.add(stringFormat(data.getLandTransferMu(), 0));
        list.add(stringFormat(data.getTotalConsArea(), 0));
        list.add(stringFormat(data.getPlotRatio(), 2));
        list.add((data.getBuildingDensity()));
        list.add((data.getGreenSpaceRatio()));
        list.add(data.getHeighPermitted());
        list.add(data.getRemiseYears());
        list.add(stringFormat(data.getTransferPrice(), 0));
        list.add(stringFormat(data.getStartingFloorPrice(), 0));
        list.add(stringFormat(data.getBidMargin(), 0));
        list.add(data.getBizRemark());
        list.add(DateUtil.fromString(data.getAnnoDate(), "yyyy-MM-dd"));
        list.add(DateUtil.fromString(data.getAnnoEndDate(), "yyyy-MM-dd"));
        list.add(DateUtil.fromString(data.getAuctionDate(), "yyyy-MM-dd"));
        list.add(stringFormat(data.getLicensedArea(), 0));
        //规划条件
        list.add(stringFormat(data.getBizSpace(), 0));
        list.add(stringFormat(data.getCommerceSpace(), 0));
        list.add(strRateFormat(data.getBizCommerceRate(), 0));
        list.add(data.getAllocationCapacity());
        list.add(data.getAllocationNotCapacity());
        //建设条件
        list.add(data.getGeologicHazard());
        list.add((data.getCivilAirDefence()));
        list.add(data.getSpecialPlan());
        list.add(data.getAssemblyBuilding());
        list.add(data.getGreenBuilding());
        list.add(data.getOtherConditions());
        list.add(stringFormat(data.getPercentFinishedHousing(), 0));
        //竞买条件
        list.add(data.getBiddingConditions());
        list.add(data.getHookForm());
        list.add(data.getFirstGovernance());
        list.add(data.getLandEnterprises());
        list.add(data.getPaymentRhythm());
        list.add(data.getBargainor());
        //地理信息
        list.add(data.getCity());
        list.add(data.getCanton());
        list.add(data.getSpecialZone());
        list.add(data.getLoopWire());
        list.add(data.getBigGroup());
        list.add(data.getSmallGroup());
        list.add(data.getOvePosition());
        list.add(data.getLonLatBd());
        //成交信息
        list.add("1".equals(data.getDeal()) ? "是" : "否");
        list.add(data.getTransferMode());
        list.add(data.getAssignee());
        list.add(data.getLandEnterpriseShort());
        list.add(stringFormat(data.getDealPrice(), 0));
        list.add(stringFormat(data.getDealFloorPrice(), 0));
        list.add(strRateFormat(data.getPremiumRate(), 0));
        list.add(strRateFormat(data.getCommercialSelfRatio(), 0));
        list.add(data.getCommercialSelfYear() == null ? "" : data.getCommercialSelfYear().toString());
        list.add((data.getHomeSelfRatio()));
        list.add(data.getHomeSelfYear() == null ? "" : data.getHomeSelfYear().toString());
        list.add(strRateFormat(data.getPercentUnpaid(), 0));
        list.add(stringFormat(data.getTalenApartmentArea(), 0));
        list.add(data.getParticipatingEnterprises());
        //项目开发
        list.add(data.getProjectStatus());
        list.add(data.getBuildingName());
        list.add(data.getProjectCompany());
        list.add(DateUtil.fromString(data.getConfirmationTime(), "yyyy-MM-dd"));
        list.add(data.getTradingEnterprises());
        list.add(data.getPartner());
        list.add(data.getConductEnterprise());
        list.add(DateUtil.fromString(data.getFirstOpenTime(), "yyyy-MM-dd"));
        return list;
    }

    /**
     * 获取有计算公式列的值
     *
     * @param cell
     * @return
     * @author peihao
     * @date 2021/6/25
     **/
    private String getCellValue(XSSFCell cell) {
        String value;
        try {
            value = cell.getRawValue();
        } catch (IllegalStateException e) {
            value = cell.toString();
        }
        return valueFormat(value);
    }

    /**
     * 获取没有计算公式列的值
     *
     * @param cell
     * @return
     * @author peihao
     * @date 2021/6/25
     **/
    private String getCellStrValue(XSSFCell cell) {
        String value = null;
        try {
            value = cell.toString();
        } catch (IllegalStateException e) {
            e.printStackTrace();
        }
        return valueFormat(value);
    }

    public String getAnnoId(XSSFCell cell) {
        try {
            Double str = Double.valueOf(cell.toString());
            Double value = Double.valueOf(cell.getRawValue());
            if (str.doubleValue() == value.doubleValue()) {
                return getCellValue(cell);
            }
        } catch (NumberFormatException e) {
            return getCellStrValue(cell);
        }
        return getCellStrValue(cell);
    }

    /**
     * 格式化列的值
     *
     * @param value
     * @return
     * @author peihao
     * @date 2021/6/25
     **/
    private String valueFormat(String value) {
        value = StrUtil.isNotEmpty(value) ? StrUtil.trim(value) : value;
        value = StrUtil.equals("-", value) ? "" : value;
        return value;
    }

    /**
     * 格式化列的值
     *
     * @param decimal 保留小数位
     * @param value   数据
     * @return
     * @author peihao
     * @date 2021/6/25
     **/
    private BigDecimal numberFormat(String value, int decimal) {
        if (StringUtils.isEmpty(value)) {
            return null;
        }
        return new BigDecimal(value).setScale(decimal, BigDecimal.ROUND_HALF_UP);
    }

    private BigDecimal numberFormat(String value, int mulitple, int decimal) {
        if (StringUtils.isEmpty(value)) {
            return null;
        }
        return new BigDecimal(value).multiply(new BigDecimal(mulitple)).setScale(decimal, BigDecimal.ROUND_HALF_UP);
    }

    /**
     * 格式化列值为字符串
     *
     * @param value   数据
     * @param decimal 保留小数位
     * @return
     * @author peihao
     * @date 2021/6/25
     **/
    private String stringFormat(BigDecimal value, int decimal) {
        if (value == null) {
            return "";
        }
        return value.setScale(decimal, BigDecimal.ROUND_HALF_UP).toString();
    }

    /**
     * 数字转换百分比
     *
     * @return
     * @author peihao
     * @date 2021/8/25
     **/
    private String strRateFormat(BigDecimal value, int decimal) {
        return value == null ? null : stringFormat(value, decimal) + "%";
    }
}
