package com.air.land.service.impl;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.air.applets.convert.LandLonLatConvert;
import com.air.applets.dto.LandLonLatDto;
import com.air.land.entity.LandListedLonLat;
import com.air.land.entity.LandToListLonLat;
import com.air.land.mapper.LandToListLonLatMapper;
import com.air.land.service.LandToListLonLatService;
import com.air.utils.ExcelUtil;
import com.air.utils.WgsUtil;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cinderella.framework.common.core.exception.BusinessException;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

/**
 * 拟挂牌地块经纬度
 *
 * @author peihao
 * @date 2021-05-18 09:40:15
 */
@Service
public class LandToListLonLatServiceImpl extends ServiceImpl<LandToListLonLatMapper, LandToListLonLat> implements LandToListLonLatService {

    @Override
    public boolean importLandToListedLonLatExcel(MultipartFile file,String proposedseriaId) {
        List<List<String>> dataList;
        try {
            dataList = ExcelUtil.importExcel(file, 0, 1, 0);
        } catch (IOException e) {
            throw new BusinessException("导入拟挂牌经纬度数据出错");
        }
        if (CollectionUtil.isNotEmpty(dataList)){
            List<LandToListLonLat> list = listToEntity(dataList,proposedseriaId);
            return this.saveBatch(list);
        }
        return false;
    }

    @Override
    public List<LandLonLatDto> getLandToListLonLat(String proposedseriaId) {
        List<LandListedLonLat> list = baseMapper.getLandToListLonLat(proposedseriaId);
        return LandLonLatConvert.getLandLonLatDto(list,3);
    }

    private List<LandToListLonLat> listToEntity(List<List<String>> dataList,String proposedseriaId) {
        List<LandToListLonLat> list = new ArrayList<>();
        for(int i = 0;i<dataList.size();i++){
            List<String> data = dataList.get(i);
            LandToListLonLat landToListLonLat = new LandToListLonLat();
            landToListLonLat.setProposedseriaId(proposedseriaId);
            landToListLonLat.setLandLonLat(data.get(0));
            landToListLonLat.setLineWidth(data.get(1));
            landToListLonLat.setLineColor(data.get(2));
            landToListLonLat.setLineOpaqueness(data.get(3));
            landToListLonLat.setFillColor(data.get(4));
            landToListLonLat.setFillOpaqueness(data.get(5));
            try {
                String landLonLat = landToListLonLat.getLandLonLat();
                if(StrUtil.isNotEmpty(landLonLat)){
                    String[] split = landLonLat.split(";");
                    landToListLonLat.setLandLonLat(new StringBuffer(landLonLat).append(";").append(split[0]).toString());
                }
                landToListLonLat.setLandLonLat(WgsUtil.wgs84_To_Gcj02(landToListLonLat.getLandLonLat()));
            } catch (Exception e) {
                e.printStackTrace();
                throw new BusinessException("导入拟挂牌经纬度数据转换出错");
            }
            list.add(landToListLonLat);
        }
        return list;
    }
}
