package com.air.land.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollectionUtil;
import com.air.common.Constant;
import com.air.land.entity.*;
import com.air.land.service.*;
import com.air.utils.WgsUtil;
import com.cinderella.framework.common.core.util.R;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.air.utils.DateUtil;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;

/**
 * 拟挂牌地块发送至已挂牌服务
 *
 * @author peihao
 * @date 2021-06-28
 **/
@Slf4j
@Service
@AllArgsConstructor
public class LandToListSendServiceImpl implements LandToListSendService {

    private LandToListService landToListService;

    private LandListedService landListedService;

    private LandListedLonLatService listedLonLatService;

    private LandToListAttachmentService toListAttachmentService;

    private LandToListLonLatService landToListLonLatService;

    private LandAttachmentService attachmentService;

    private LandToListConductEnterpriseService landToListConductEnterpriseService;

    private LandListedConductEnterpriseService landListedConductEnterpriseService;

    private LandToListConstructionPlanService landToListConstructionPlanService;

    private LandListedConstructionPlanService landListedConstructionPlanService;

    @Transactional(rollbackFor = Exception.class)
    @Override
    public R<Boolean> landToListSendLandListed(String proposedseriaId) {
        LandToList landToList = landToListService.getById(proposedseriaId);
        if (null == landToList) {
            return R.failed("未查询到数据");
        }
        //判断已挂牌是否已经存在次公告id
        LandListed land = landListedService.getOne(Wrappers.<LandListed>query().lambda().eq(LandListed::getAnnoId, landToList.getAnnoId()));
        if (land == null){
            return R.failed("发送失败，公告序号不存在！");
        }
        //更新已挂牌数据
        landListedService.updateById(convertLandListed(land,landToList));
        //更新经纬度数据
        listedLonLatService.remove(Wrappers.<LandListedLonLat>query().lambda().eq(LandListedLonLat::getLandListedId, land.getLandListedId()));
        saveLandListedLonLat(proposedseriaId, land.getLandListedId());
        //更新文件信息
        attachmentService.remove(Wrappers.<LandAttachment>query().lambda().eq(LandAttachment::getLandListedId, land.getLandListedId()));
        saveLandListAttachment(proposedseriaId, land.getLandListedId());
        //更新地块关联经营企业
        landListedConductEnterpriseService.remove(Wrappers.<LandListedConductEnterprise>query().lambda().eq(LandListedConductEnterprise::getLandListedId, land.getLandListedId()));
        saveLandListConductEnterprise(proposedseriaId, land.getLandListedId());
        //更新地块关联建设规划
        landListedConstructionPlanService.remove(Wrappers.<LandListedConstructionPlan>query().lambda().eq(LandListedConstructionPlan::getLandListedId, land.getLandListedId()));
        saveLandListConstructionPlan(proposedseriaId, land.getLandListedId());
        return R.ok();
    }

    /**
     * 拟挂牌地块转换已挂牌地块
     * @author peihao
     * @param land 已挂牌地块
     * @param landToList 拟挂牌地块
     * @date 2021/8/30
     * @return
     **/
    public LandListed convertLandListed(LandListed land,LandToList landToList){
        LandListed landListed = new LandListed();
        BeanUtil.copyProperties(landToList,landListed);
        landListed.setLandListedId(land.getLandListedId());
        landListed.setAnnoId(land.getAnnoId());
        landListed.setLandCode(land.getLandCode());
        landListed.setLandPosition(land.getLandPosition());
        landListed.setLandUsage(land.getLandUsage());
        landListed.setLandTransferSquare(land.getLandTransferSquare());
        landListed.setLandTransferMu(land.getLandTransferMu());
        landListed.setTotalConsArea(land.getTotalConsArea());
        landListed.setPlotRatio(land.getPlotRatio());
        landListed.setBuildingDensity(land.getBuildingDensity());
        landListed.setHeighPermitted(land.getHeighPermitted());
        landListed.setRemiseYears(land.getRemiseYears());
        landListed.setTransferPrice(land.getTransferPrice());
        landListed.setStartingFloorPrice(land.getStartingFloorPrice());
        landListed.setBidMargin(land.getBidMargin());
        landListed.setBizRemark(land.getBizRemark());
        landListed.setAnnoDate(land.getAnnoDate());
        landListed.setAnnoEndDate(land.getAnnoEndDate());
        landListed.setAuctionDate(land.getAuctionDate());
        landListed.setLicensedArea(land.getLicensedArea());
        return landListed;
    }

    /**
     * 保存地块经纬度
     * @author peihao
     * @param proposedseriaId 拟挂牌地块id
     * @param landListedId 已挂牌地块id
     * @date 2021/6/29
     * @return
     **/
    @Transactional(rollbackFor = Exception.class)
    public boolean saveLandListedLonLat(String proposedseriaId, String landListedId) {
        List<LandToListLonLat> landToListLonLats = landToListLonLatService.list(Wrappers.<LandToListLonLat>query().lambda()
                .eq(LandToListLonLat::getProposedseriaId, proposedseriaId));
        if (CollectionUtil.isNotEmpty(landToListLonLats)) {
            List<LandListedLonLat> landListedLonLats = new ArrayList<>(landToListLonLats.size());
            landToListLonLats.forEach(landToListLonLat -> {
                LandListedLonLat landListedLonLat = new LandListedLonLat();
                BeanUtil.copyProperties(landToListLonLat, landListedLonLat);
                landListedLonLat.setLandListedId(landListedId);
                //转换经纬度标准格式
                landListedLonLat.setLandLonLat(WgsUtil.wgs84_To_Gcj02(landToListLonLat.getLandLonLat()));
                landListedLonLats.add(landListedLonLat);
            });
            return listedLonLatService.saveBatch(landListedLonLats);
        }
        return true;
    }

    /**
     * 保存地块文件信息
     * @author peihao
     * @param proposedseriaId 拟挂牌地块id
     * @param landListedId 已挂牌地块id
     * @date 2021/6/29
     * @return
     **/
    @Transactional(rollbackFor = Exception.class)
    public boolean saveLandListAttachment(String proposedseriaId, String landListedId) {
        List<LandToListAttachment> toListAttachments = toListAttachmentService.list(Wrappers.<LandToListAttachment>query().lambda()
                .eq(LandToListAttachment::getProposedseriaId, proposedseriaId));
        if (CollectionUtil.isNotEmpty(toListAttachments)) {
            List<LandAttachment> landAttachments = new ArrayList<>(toListAttachments.size());
            toListAttachments.forEach(landToListAttachment -> {
                LandAttachment attachment = new LandAttachment();
                BeanUtil.copyProperties(landToListAttachment, attachment);
                attachment.setLandListedId(landListedId);
                landAttachments.add(attachment);
            });
            return attachmentService.saveBatch(landAttachments);
        }
        return true;
    }

    /**
     * 保存地块关联经营企业
     * @author peihao
     * @param proposedseriaId 拟挂牌地块id
     * @param landListedId 已挂牌地块id
     * @date 2021/6/29
     * @return
     **/
    @Transactional(rollbackFor = Exception.class)
    public boolean saveLandListConductEnterprise(String proposedseriaId, String landListedId) {
        List<LandToListConductEnterprise> landToListConductEnterprises = landToListConductEnterpriseService.list(Wrappers.<LandToListConductEnterprise>query()
                .lambda().eq(LandToListConductEnterprise::getProposedseriaId, proposedseriaId));
        if (CollectionUtil.isNotEmpty(landToListConductEnterprises)) {
            List<LandListedConductEnterprise> landListedConductEnterprises = new ArrayList<>(landToListConductEnterprises.size());
            landToListConductEnterprises.forEach(landToListConductEnterprise -> {
                LandListedConductEnterprise landListedConductEnterprise = new LandListedConductEnterprise();
                BeanUtil.copyProperties(landToListConductEnterprise, landListedConductEnterprise);
                landListedConductEnterprise.setLandListedId(landListedId);
                landListedConductEnterprises.add(landListedConductEnterprise);
            });
            return landListedConductEnterpriseService.saveBatch(landListedConductEnterprises);
        }
        return true;
    }

    /**
     * 保存地块关联建设规划
     * @author peihao
     * @param proposedseriaId 拟挂牌地块id
     * @param landListedId 已挂牌地块id
     * @date 2021/6/29
     * @return
     **/
    @Transactional(rollbackFor = Exception.class)
    public boolean saveLandListConstructionPlan(String proposedseriaId, String landListedId) {
        List<LandToListConstructionPlan> landToListConstructionPlans = landToListConstructionPlanService.list(Wrappers.<LandToListConstructionPlan>query()
                .lambda().eq(LandToListConstructionPlan::getProposedseriaId, proposedseriaId));
        if (CollectionUtil.isNotEmpty(landToListConstructionPlans)) {
            List<LandListedConstructionPlan> landListedConstructionPlans = new ArrayList<>(landToListConstructionPlans.size());
            landToListConstructionPlans.forEach(landToListConstructionPlan -> {
                LandListedConstructionPlan landListedConstructionPlan = new LandListedConstructionPlan();
                BeanUtil.copyProperties(landToListConstructionPlan, landListedConstructionPlan);
                landListedConstructionPlan.setLandListedId(landListedId);
                landListedConstructionPlans.add(landListedConstructionPlan);
            });
            return landListedConstructionPlanService.saveBatch(landListedConstructionPlans);
        }
        return true;
    }


}
