package com.air.land.vo;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import javax.validation.constraints.NotBlank;
import java.math.BigDecimal;
import java.time.LocalDate;

/**
 * 已挂牌地块保存参数
 *
 * @author peihao
 * @date 2021/5/18
 **/
@Data
@ApiModel(value = "已挂牌地块保存参数")
public class LandListedVo {
    private static final long serialVersionUID = 1L;

    @ApiModelProperty(value = "id,主键")
    private String landListedId;

    @NotBlank(message = "公告id不能为空")
    @ApiModelProperty(value = "公告id", required = true)
    private String annoId;

    @ApiModelProperty(value = "地块编号")
    private String landCode;
    @ApiModelProperty(value = "地块位置")
    private String landPosition;
    @ApiModelProperty(value = "土地用途")
    private String landUsage;
    @ApiModelProperty(value = "土地出让面积(㎡)")
    private BigDecimal landTransferSquare;
    @ApiModelProperty(value = "土地出让面积-亩")
    private BigDecimal landTransferMu;
    @ApiModelProperty(value = "总计容建筑面积(㎡)")
    private BigDecimal totalConsArea;
    @ApiModelProperty(value = "容积率")
    private BigDecimal plotRatio;
    @ApiModelProperty(value = "建筑密度(%)")
    private BigDecimal buildingDensity;
    @ApiModelProperty(value = "绿地率(%)")
    private BigDecimal greenSpaceRatio;
    @ApiModelProperty(value = "限高")
    private String heighPermitted;
    @ApiModelProperty(value = "出让年限")
    private String remiseYears;
    @ApiModelProperty(value = "出让价款起始价（万元）")
    private BigDecimal transferPrice;
    @ApiModelProperty(value = "起始楼面价(元/㎡)")
    private BigDecimal startingFloorPrice;
    @ApiModelProperty(value = "竞买保证金（万元）")
    private BigDecimal bidMargin;
    @ApiModelProperty(value = "备注（业务字段）")
    private String bizRemark;
    @ApiModelProperty(value = "公告开始日期")
    private LocalDate annoDate;
    @ApiModelProperty(value = "公告截止日期")
    private LocalDate annoEndDate;
    @ApiModelProperty(value = "拍卖日期")
    private LocalDate auctionDate;
    @ApiModelProperty(value = "持证准用面积(㎡)")
    private BigDecimal licensedArea;
    @ApiModelProperty(value = "")
    private String url;
    @ApiModelProperty(value = "商业面积(㎡)")
    private BigDecimal bizSpace;
    @ApiModelProperty(value = "商务面积(㎡)")
    private BigDecimal commerceSpace;
    @ApiModelProperty(value = "商业商务占比(%)")
    private BigDecimal bizCommerceRate;
    @ApiModelProperty(value = "配建-计容(㎡)")
    private String allocationCapacity;
    @ApiModelProperty(value = "配建-不计容(㎡)")
    private String allocationNotCapacity;
    @ApiModelProperty(value = "地质灾害(无,高,中,低)")
    private String geologicHazard;
    @ApiModelProperty(value = "人防还建（㎡)")
    private BigDecimal civilAirDefence;
    @ApiModelProperty(value = "特殊条件")
    private String specialPlan;
    @ApiModelProperty(value = "装配要求")
    private String assemblyBuilding;
    @ApiModelProperty(value = "绿色要求")
    private String greenBuilding;
    @ApiModelProperty(value = "其他条件")
    private String otherConditions;
    @ApiModelProperty(value = "成品住宅比例(%)")
    private BigDecimal percentFinishedHousing;
    @ApiModelProperty(value = "竞买条件")
    private String biddingConditions;
    @ApiModelProperty(value = "勾地形式")
    private String hookForm;
    @ApiModelProperty(value = "一级治理方")
    private String firstGovernance;
    @ApiModelProperty(value = "勾地企业")
    private String landEnterprises;
    @ApiModelProperty(value = "付款节奏")
    private String paymentRhythm;
    @ApiModelProperty(value = "出让人")
    private String bargainor;
    @ApiModelProperty(value = "城市")
    private String city;
    @ApiModelProperty(value = "行政区")
    private String canton;
    @ApiModelProperty(value = "特区")
    private String specialZone;
    @ApiModelProperty(value = "环线")
    private String loopWire;
    @ApiModelProperty(value = "大组团")
    private String bigGroup;
    @ApiModelProperty(value = "小组团")
    private String smallGroup;
    @ApiModelProperty(value = "奥维定位")
    private String ovePosition;
    @ApiModelProperty(value = "经纬度（百度BD09）")
    private String lonLatBd;
    @ApiModelProperty(value = "是否成交(是,否)")
    private String deal;
    @ApiModelProperty(value = "出让方式(拍卖,挂牌,协议,其他)")
    private String transferMode;
    @ApiModelProperty(value = "受让单位")
    private String assignee;
    @ApiModelProperty(value = "拿地企业-简称")
    private String landEnterpriseShort;
    @ApiModelProperty(value = "成交价(万元)")
    private BigDecimal dealPrice;
    @ApiModelProperty(value = "成交楼面价(元/㎡)")
    private BigDecimal dealFloorPrice;
    @ApiModelProperty(value = "参拍企业")
    private String participatingEnterprises;
    @ApiModelProperty(value = "溢价率(%)")
    private BigDecimal premiumRate;
    @ApiModelProperty(value = "商业自持比例(%)")
    private BigDecimal commercialSelfRatio;
    @ApiModelProperty(value = "商业自持年份(年)")
    private Integer commercialSelfYear;
    @ApiModelProperty(value = "住宅自持比例(%)")
    private BigDecimal homeSelfRatio;
    @ApiModelProperty(value = "住宅自持年份(年)")
    private Integer homeSelfYear;
    @ApiModelProperty(value = "无偿比例(%)")
    private BigDecimal percentUnpaid;
    @ApiModelProperty(value = "人才公寓面积(㎡)")
    private BigDecimal talenApartmentArea;
    @ApiModelProperty(value = "项目状态")
    private String projectStatus;
    @ApiModelProperty(value = "楼盘名称")
    private String buildingName;
    @ApiModelProperty(value = "项目公司")
    private String projectCompany;
    @ApiModelProperty(value = "确权时间")
    private LocalDate confirmationTime;
    @ApiModelProperty(value = "操盘企业")
    private String tradingEnterprises;
    @ApiModelProperty(value = "合作方")
    private String partner;
    @ApiModelProperty(value = "经营企业")
    private String conductEnterprise;
    @ApiModelProperty(value = "项目首开时间")
    private LocalDate firstOpenTime;
    @ApiModelProperty(value = "规划条件函")
    private String planningConditionsLetter;
    @ApiModelProperty(value = "红线图")
    private String redLineMap;
    @ApiModelProperty(value = "控规图")
    private String controlChart;
    @ApiModelProperty(value = "竞买须知")
    private String biddingNotice;
    @ApiModelProperty(value = "出让合同模板")
    private String transferContractTemplate;
    @ApiModelProperty(value = "建设方案")
    private String developmentScheme;
    @ApiModelProperty(value = "航拍图片")
    private String aerialPhoto;
    @ApiModelProperty(value = "航拍链接")
    private String aerialLink;
    @ApiModelProperty(value = "拍地记录")
    private String recordTaken;
    @ApiModelProperty(value = "其他资料")
    private String otherInfo;

}
