package com.air.macro.controller;

import cn.hutool.core.util.StrUtil;
import com.air.macro.entity.MacroData;
import com.air.macro.service.MacroDataService;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.cinderella.framework.common.core.util.R;
import com.cinderella.framework.common.data.mybatis.QueryPage;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;


/**
 * 宏观数据
 * @author fnmdx
 */
@RestController
@AllArgsConstructor
@RequestMapping("/microdata")
@Api(value = "microdata", tags = "宏观数据管理")
public class MacroDataController {

    private final MacroDataService macroDataService;

    /**
     * 分页查询
     *
     * @param page      分页对象
     * @param macroData 宏观数据
     * @return
     */
    @ApiOperation(value = "分页查询", notes = "分页查询")
    @GetMapping("/page")
    public R getMacroDataPage(Page page, MacroData macroData) {
        Page page1 = macroDataService.page(page, Wrappers.<MacroData>query().lambda()
                .eq(StrUtil.isNotEmpty(macroData.getYear()), MacroData::getYear, macroData.getYear())
                .eq(StrUtil.isNotEmpty(macroData.getCity()), MacroData::getCity, macroData.getCity())
                .orderByDesc(MacroData::getCreateDate));
        return R.ok(page1);
    }


    /**
     * 通过id查询宏观数据
     *
     * @param dataId id
     * @return R
     */
    @ApiOperation(value = "通过id查询", notes = "通过id查询")
    @GetMapping("/{dataId}")
    public R getById(@PathVariable("dataId") Long dataId) {
        return R.ok(macroDataService.getMacroDataDetail(dataId));
    }

    /**
     * 新增宏观数据
     *
     * @param macroData 宏观数据
     * @return R
     */
    @ApiOperation(value = "新增宏观数据", notes = "新增宏观数据")
    @PostMapping
    public R save(@RequestBody MacroData macroData) {
        return R.ok(macroDataService.saveMacroData(macroData));
    }

    /**
     * 修改宏观数据
     *
     * @param macroData 宏观数据
     * @return R
     *
     *
     */
    @ApiOperation(value = "修改宏观数据", notes = "修改宏观数据")
    @PutMapping
    public R updateById(@RequestBody MacroData macroData) {
        return R.ok(macroDataService.updateMacroData(macroData));
    }

    /**
     * 通过id删除宏观数据
     *
     * @param dataIds id
     * @return R
     */
    @ApiOperation(value = "通过id删除宏观数据", notes = "通过id删除宏观数据")
    @DeleteMapping
    public R removeById(@RequestBody List<Long> dataIds) {
        return R.ok(macroDataService.removeByIds(dataIds));
    }
}
