package com.air.msgUserRel.controller;

import com.air.msgUserRel.entity.MsgUserRel;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.cinderella.framework.common.core.util.R;
import com.air.msgUserRel.service.MsgUserRelService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.*;


/**
 * 消息用户关联表
 *
 * @author fnmdx
 * @date 2021-05-25 10:52:20
 */
@RestController
@AllArgsConstructor
@RequestMapping("/msguserrel")
@Api(value = "msguserrel", tags = "消息用户关联表管理")
public class MsgUserRelController {

    private final  MsgUserRelService msgUserRelService;

    /**
     * 分页查询
     * @param page 分页对象
     * @param msgUserRel 消息用户关联表
     * @return
     */
    @ApiOperation(value = "分页查询", notes = "分页查询")
    @GetMapping("/page")
    public R getMsgUserRelPage(Page page, MsgUserRel msgUserRel) {
        return R.ok(msgUserRelService.page(page, Wrappers.query(msgUserRel)));
    }


    /**
     * 通过id查询消息用户关联表
     * @param messageId id
     * @return R
     */
    @ApiOperation(value = "通过id查询", notes = "通过id查询")
    @GetMapping("/{messageId}")
    public R getById(@PathVariable("messageId") Long messageId) {
        return R.ok(msgUserRelService.getById(messageId));
    }

    /**
     * 新增消息用户关联表
     * @param msgUserRel 消息用户关联表
     * @return R
     */
    @ApiOperation(value = "新增消息用户关联表", notes = "新增消息用户关联表")
    @PostMapping
    public R save(@RequestBody MsgUserRel msgUserRel) {
        return R.ok(msgUserRelService.save(msgUserRel));
    }

    /**
     * 修改消息用户关联表
     * @param msgUserRel 消息用户关联表
     * @return R
     */
    @ApiOperation(value = "修改消息用户关联表", notes = "修改消息用户关联表")
    @PutMapping
    public R updateById(@RequestBody MsgUserRel msgUserRel) {
        return R.ok(msgUserRelService.updateById(msgUserRel));
    }

    /**
     * 通过id删除消息用户关联表
     * @param messageId id
     * @return R
     */
    @ApiOperation(value = "通过id删除消息用户关联表", notes = "通过id删除消息用户关联表")
    @DeleteMapping("/{messageId}")
    public R removeById(@PathVariable Long messageId) {
        return R.ok(msgUserRelService.removeById(messageId));
    }
}
