package com.air.origin.controller;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.cinderella.framework.common.core.util.R;
import com.air.origin.entity.HousesOrigin;
import com.air.origin.service.HousesOriginService;
import com.cinderella.framework.common.data.mybatis.QueryPage;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.*;


/**
 * 房屋信息
 *
 * @author zeb
 * @date 2021-06-08 11:35:24
 */
@RestController
@AllArgsConstructor
@RequestMapping("/houses_origin")
@Api(value = "houses_origin", tags = "房屋信息管理")
public class HousesOriginController {

    private final  HousesOriginService housesOriginService;

    /**
     * 分页查询
     * @param page 分页对象
     * @param housesOrigin 房屋信息
     * @return
     */
    @ApiOperation(value = "分页查询", notes = "分页查询")
    @GetMapping("/page")
    public R getHousesOriginPage(QueryPage page, HousesOrigin housesOrigin) {
        return R.ok(housesOriginService.page(page.toPage(), Wrappers.query(housesOrigin)));
    }


    /**
     * 通过id查询房屋信息
     * @param houseId id
     * @return R
     */
    @ApiOperation(value = "通过id查询", notes = "通过id查询")
    @GetMapping("/{houseId}")
    public R getById(@PathVariable("houseId") Long houseId) {
        return R.ok(housesOriginService.getById(houseId));
    }

    /**
     * 新增房屋信息
     * @param housesOrigin 房屋信息
     * @return R
     */
    @ApiOperation(value = "新增房屋信息", notes = "新增房屋信息")
    @PostMapping
    public R save(@RequestBody HousesOrigin housesOrigin) {
        return R.ok(housesOriginService.save(housesOrigin));
    }

    /**
     * 修改房屋信息
     * @param housesOrigin 房屋信息
     * @return R
     */
    @ApiOperation(value = "修改房屋信息", notes = "修改房屋信息")
    @PutMapping
    public R updateById(@RequestBody HousesOrigin housesOrigin) {
        return R.ok(housesOriginService.updateById(housesOrigin));
    }

    /**
     * 通过id删除房屋信息
     * @param houseId id
     * @return R
     */
    @ApiOperation(value = "通过id删除房屋信息", notes = "通过id删除房屋信息")
    @DeleteMapping("/{houseId}")
    public R removeById(@PathVariable Long houseId) {
        return R.ok(housesOriginService.removeById(houseId));
    }
}
