package com.air.utils;

import cn.hutool.core.util.StrUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;

import java.text.SimpleDateFormat;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.ZoneId;
import java.time.format.DateTimeFormatter;
import java.util.Date;

/**
 * 时间工具
 *
 * @author peihao
 * @date 2020-06-28
 **/
@Slf4j
public class DateUtil {

    /**
     * 一分钟
     */
    private static final long ONE_MINUTE = 60;
    /**
     * 一小时
     */
    private static final long ONE_HOUR = 3600;
    /**
     * 一天
     */
    private static final long ONE_DAY = 86400;


    /**
     * 距离今天多久
     *
     * @param date 时间
     * @return
     * @author peihao
     * @date 2020/6/28
     **/
    public static String fromToday(Date date) {
        long time = date.getTime() / 1000;
        long now = System.currentTimeMillis() / 1000;
        long ago = now - time;
        if (ago <= ONE_HOUR) {
            return ago / ONE_MINUTE + "分钟前";
        } else if (ago <= ONE_DAY) {
            return ago / ONE_HOUR + "小时" + (ago % ONE_HOUR / ONE_MINUTE) + "分钟前";
        } else {
            return new SimpleDateFormat("yyyy-MM-dd").format(date);
        }
    }

    /**
     * 字符串转时间
     *
     * @param dateString 时间
     * @return
     * @author peihao
     * @date 2020/6/28
     **/
    public static LocalDate fromLocalDate(String dateString, String pattern) {
        if (StrUtil.isEmpty(dateString)) {
            return null;
        }
        DateTimeFormatter fmt = DateTimeFormatter.ofPattern(pattern);
        return LocalDate.parse(dateString, fmt);
    }

    /**
     * 字符串转时间
     *
     * @param dateString 时间
     * @return
     * @author peihao
     * @date 2020/6/28
     **/
    public static LocalDateTime fromLocalDateTime(String dateString, String pattern) {
        LocalDate localDate = fromLocalDate(dateString, pattern);
        return localDate.atStartOfDay();
    }

    /**
     * date转 LocalDate
     *
     * @param date 时间
     * @return
     * @author peihao
     * @date 2020/6/28
     **/
    public static LocalDate dateToLocalDate(Date date) {
        if (null == date) {
            return null;
        }
        LocalDate localDate = null;
        try {
            localDate = date.toInstant().atZone(ZoneId.systemDefault()).toLocalDate();
        } catch (Exception e) {
            log.error("时间格式解析错误：", e);
        }
        return localDate;
    }

    /**
     * 字符串转时间
     *
     * @param dateString 时间
     * @return
     * @author peihao
     * @date 2020/6/28
     **/
    public static String fromString(LocalDate dateString, String pattern) {
        if (null == dateString || StringUtils.isEmpty(pattern)) {
            return "";
        }
        DateTimeFormatter fmt = DateTimeFormatter.ofPattern(pattern);
        return fmt.format(dateString);
    }

    public static String landListedIdfromDate(LocalDateTime dateString, String pattern, Integer sequence) {
        DateTimeFormatter fmt = DateTimeFormatter.ofPattern(pattern);
        String seq = String.format("%04d", Integer.parseInt("0000") + sequence);
        return "CQ" + fmt.format(dateString) + seq;
    }

    public static String landToListIdfromDate(LocalDateTime dateString, String pattern, Integer sequence) {
        DateTimeFormatter fmt = DateTimeFormatter.ofPattern(pattern);
        String seq = String.format("%04d", Integer.parseInt("0000") + sequence);
        return "NICQ" + fmt.format(dateString) + seq;
    }

}
