package com.air.utils;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.io.resource.ResourceUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.air.cityarea.entity.Dazutuan;
import com.air.cityarea.entity.Xiaozutuan;
import com.air.common.entity.ExcelConfig;
import com.cinderella.framework.common.core.exception.BusinessException;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.xssf.streaming.SXSSFCell;
import org.apache.poi.xssf.streaming.SXSSFRow;
import org.apache.poi.xssf.streaming.SXSSFSheet;
import org.apache.poi.xssf.streaming.SXSSFWorkbook;
import org.apache.poi.xssf.usermodel.XSSFCell;
import org.apache.poi.xssf.usermodel.XSSFRow;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.io.InputStream;
import java.math.BigDecimal;
import java.nio.charset.Charset;
import java.util.*;
import java.util.stream.Collectors;
import java.util.stream.Stream;

/**
 * excel表格工具类
 *
 * @author peihao
 * @date 2021-05-31
 **/
@Slf4j
public class ExcelUtil {


    /**
     * 数据导出
     *
     * @param dataList    导出数据
     * @param inputStream 模板流
     * @param startRow    开始导出行
     * @return
     * @author peihao
     * @date 2021/6/17
     **/
    public static XSSFWorkbook exportLandListedExcel(List<List<String>> dataList, InputStream inputStream, int startRow) throws IOException {
        long startTime = System.currentTimeMillis();
        // 读取excel模板
//        XSSFWorkbook wb = new XSSFWorkbook(inputStream);
//        SXSSFWorkbook swb = new SXSSFWorkbook(wb);
//        SXSSFSheet sheet = swb.getSheetAt(0);
//        //填充数据
//        for (int i = 0; i < dataList.size(); i++) {
//            SXSSFRow sheetRow = sheet.getRow(i + startRow);
//            if (sheetRow == null) {
//                sheetRow = sheet.createRow(i + startRow);
//            }
//            List<String> list = dataList.get(i);
//            for (int j = 0; j < list.size(); j++) {
//                String value = list.get(j);
//                SXSSFCell cell = sheetRow.getCell(j);
//                if (cell == null) {
//                    cell = sheetRow.createCell(j);
//                }
//                cell.setCellValue(value);
//            }
//        }
//        //swb.dispose();// 释放workbook所占用的全部windows资源
//        long endTime = System.currentTimeMillis();
//        System.out.println("耗时"+(endTime-startTime));
//        return wb;

        // 读取excel模板
        XSSFWorkbook wb = new XSSFWorkbook(inputStream);
//        SXSSFWorkbook swb = new SXSSFWorkbook(wb);
        XSSFSheet sheet = wb.getSheetAt(0);
        //填充数据
        for (int i = 0; i < dataList.size(); i++) {
            XSSFRow sheetRow = sheet.getRow(i + startRow);
            if (sheetRow == null) {
                sheetRow = sheet.createRow(i + startRow);
            }
            List<String> list = dataList.get(i);
            for (int j = 0; j < list.size(); j++) {
                String value = list.get(j);
                XSSFCell cell = sheetRow.getCell(j);
                if (cell == null) {
                    cell = sheetRow.createCell(j);
                }
                cell.setCellValue(value);
            }
        }
        long endTime = System.currentTimeMillis();
        System.out.println("耗时"+(endTime-startTime));
        return wb;
    }

    /**
     * 导入数据
     *
     * @param file       导入文件
     * @param startSheet 第几个sheet
     * @param startRow   开始读取行
     * @param startCell  开始读取列
     * @return
     * @author peihao
     * @date 2021/6/17
     **/
    public static List<List<String>> importExcel(MultipartFile file, int startSheet, int startRow, int startCell) throws IOException {
        // 读取excel模板
        XSSFWorkbook wb = new XSSFWorkbook(file.getInputStream());
        XSSFSheet sheet = wb.getSheetAt(startSheet);
        int rowSum = sheet.getPhysicalNumberOfRows();
        //获取数据
        List<List<String>> result = new ArrayList<>();
        for (int i = startRow; i < rowSum; i++) {
            XSSFRow sheetRow = sheet.getRow(i);
            List<String> list = new ArrayList<>();
            for (int j = startCell; j < sheetRow.getPhysicalNumberOfCells(); j++) {
                String value;
                XSSFCell cell = sheetRow.getCell(j);
                try {
                    cell.getCellFormula();
                    value = cell.getRawValue();
                } catch (IllegalStateException e) {
                    value = cell.toString();
                }
                value = StringUtils.isNotEmpty(value) ? value.trim() : value;
                value = StringUtils.equals("-", value) ? "" : value;
                list.add(value);
            }
            result.add(list);
        }

        return result;
    }

    /**
     * 导入数据解析
     *
     * @param fileInputStream 文件流
     * @param startSheet      读取的sheet
     * @param titleRow        表头行
     * @param titleColumn     开始列
     * @param clazz           返回数据类
     * @param path            配置文件路径
     * @return
     * @author peihao
     * @date 2021/10/13
     **/
    public static <T> List<T>  importExcel(InputStream fileInputStream, int startSheet, int titleRow, int titleColumn, Class<T> clazz, String path) throws IOException {
        //读取文件的指定sheet
        XSSFWorkbook workbook = new XSSFWorkbook(fileInputStream);
        XSSFSheet sheet = workbook.getSheetAt(startSheet);
        //总行数
        int totalRows = sheet.getPhysicalNumberOfRows();
        //读取表头,设置对应列索引
        List<ExcelConfig> excelConfigList = getExcelJsonConfig(path, ExcelConfig.class);
        XSSFRow sheetRow = sheet.getRow(titleRow);
        int totalColumns = sheetRow.getPhysicalNumberOfCells();
        //获取每个表头在excel中的列
        for (int i = titleColumn; i < totalColumns; i++) {
            String cellStrValue = getCellStrValue(sheetRow.getCell(i));
            Optional<ExcelConfig> excelConfig = excelConfigList.stream().filter(item -> item.getTitleName().equals(cellStrValue)).findAny();
            if (excelConfig.isPresent()) {
                excelConfig.get().setColumn(i);
            }
        }
        //判断是否有为空的数据
        Optional<ExcelConfig> any = excelConfigList.stream().filter(e -> e.getColumn() == null).findAny();
        if (any.isPresent() && any.get().isRequired()) {
            throw new BusinessException(any.get().getTitleName() + "列不能为空");
        }
        //读取数据
        List<Map<String, Object>> mapList = new ArrayList<>();
        for (int i = titleRow + 1; i < totalRows; i++) {
            Map<String, Object> map = new HashMap<>();
            XSSFRow row = sheet.getRow(i);
            for (ExcelConfig excelConfig : excelConfigList) {
                try {

                    Object value = getCellString(row.getCell(excelConfig.getColumn()), excelConfig.getValueType());
                    map.put(excelConfig.getFieldName(), value);
                } catch (Exception e) {
                    log.error("解析出错：", e);
                    throw new BusinessException("第" + (i+1) + "行，第" + excelConfig.getTitleName() + "列数据解析出现错误");
                }
            }
            mapList.add(map);
        }

        return mapList.stream().map(e -> BeanUtil.mapToBean(e, clazz, true)).collect(Collectors.toList());
    }

    public static void main(String[] args) {
        List<Dazutuan> dazutuans = new ArrayList<>();
        for (int i=1;i<3;i++){
            Dazutuan dazutuan = new Dazutuan();
            dazutuan.setId(i);
            dazutuan.setPos("shezhi"+i);
            dazutuans.add(dazutuan);
        }

        List<Xiaozutuan> xiaozutuans = new ArrayList<>();

        for (int i=1;i<3;i++){
            Xiaozutuan xiaozutuan = new Xiaozutuan();
            xiaozutuan.setId(i);
            xiaozutuan.setPos("shezhiwoshuo"+i);
            xiaozutuans.add(xiaozutuan);
        }
        List<Dazutuan> convert = convert(xiaozutuans,dazutuans);
        convert.stream().forEach(e->{
            System.out.println(e.getId());
            System.out.println(e.getPos());
        });

    }

    private static List<Dazutuan> convert(List<Xiaozutuan> xiaozutuans,List<Dazutuan> dazutuans){
        List<Dazutuan> collect = xiaozutuans.stream().map(item -> getDazutuan(dazutuans, item)).collect(Collectors.toList());
        return collect;
    }

    private static Dazutuan getDazutuan(List<Dazutuan> dazutuans,Xiaozutuan xiaozutuan){
        Dazutuan dazutuan = dazutuans.stream().filter(item -> xiaozutuan.getId().equals(item.getId())).findFirst()
                .map(e -> {
                    Dazutuan dazutuan1 = new Dazutuan();
                    dazutuan1.setId(e.getId());
                    dazutuan1.setPos(xiaozutuan.getPos());
                    return dazutuan1;
                }).orElse(new Dazutuan());
        return dazutuan;
    }

    /**
     * 读取excel数据列模板配置
     *
     * @param path  配置文件路径
     * @param clazz 配置实体类
     * @return
     * @author peihao
     * @date 2021/10/13
     **/
    public static <T> List<T> getExcelJsonConfig(String path, Class<T> clazz) {
        String config = ResourceUtil.readStr(path, Charset.defaultCharset());
        return JSONUtil.parseArray(config).stream().map(e -> JSONUtil.toBean((JSONObject) e, clazz)).collect(Collectors.toList());
    }

    /**
     * 根据不同的数据类型获取列的值
     *
     * @param cell      列
     * @param valueType 数据类型
     * @return
     * @author peihao
     * @date 2021/10/13
     **/
    public static Object getCellString(XSSFCell cell, String valueType) {
        String cellStrValue = getCellStrValue(cell);
        switch (valueType) {
            case "string":
                return cellStrValue;
            case "BigDecimal":
                return numberFormat(cellStrValue, 0);
            case "BigDecimal_mu":
                return numberFormat(cellStrValue, 100, 0);
            case "BigDecimal_2":
                return numberFormat(cellStrValue, 2);
            case "Integer":
                return StrUtil.isEmpty(cellStrValue) ? null : Integer.valueOf(cellStrValue);
            case "LocalDate":
                return dateFormat(cell);
            case "enum":
                return getEnumValue(cellStrValue);
            default:
                return null;
        }
    }

    /**
     * 字符串转换数字
     *
     * @param decimal 保留小数位
     * @param value   数据
     * @return
     * @author peihao
     * @date 2021/6/25
     **/
    private static BigDecimal numberFormat(String value, int decimal) {
        if (StringUtils.isEmpty(value)) {
            return null;
        }
        try {


            return new BigDecimal(value).setScale(decimal, BigDecimal.ROUND_HALF_UP);

        }catch (Exception e){
            value=value.replaceAll("%","");
            return new BigDecimal(value).setScale(decimal, BigDecimal.ROUND_HALF_UP);

        }


    }

    /**
     * 字符串转换数字
     *
     * @param decimal  保留小数位
     * @param value    数据
     * @param mulitple 倍数
     * @return
     * @author peihao
     * @date 2021/6/25
     **/
    private static BigDecimal numberFormat(String value, int mulitple, int decimal) {
        if (StringUtils.isEmpty(value)) {
            return null;
        }

        try {


            return new BigDecimal(value).multiply(new BigDecimal(mulitple)).setScale(decimal, BigDecimal.ROUND_HALF_UP);

        }catch (Exception e){
            value=value.replaceAll("%","");
            e.printStackTrace();
            return new BigDecimal(value).setScale(decimal, BigDecimal.ROUND_HALF_UP);

        }
    }

    /**
     * 获取单元格的值
     *
     * @param cell 单元格
     * @return
     * @author peihao
     * @date 2021/10/13
     **/
    public static String getCellStrValue(XSSFCell cell) {
        if (cell == null) {
            return null;
        }
        String value;
        try {
            value = cell.getStringCellValue();
        } catch (Exception e) {
            value = cell.getRawValue();
        }
        return valueFormat(value);
    }

    /**
     * 去除字符串中的空格和'-'
     *
     * @param value
     * @return
     * @author peihao
     * @date 2021/10/13
     **/
    private static String valueFormat(String value) {
        value = StringUtils.isNotEmpty(value) ? StrUtil.trim(value) : value;
        value = StringUtils.equals("-", value) ? "" : value;
        return value;
    }

    /**
     * 获取单元格时间
     *
     * @param cell 单元格
     * @return
     * @author peihao
     * @date 2021/10/13
     **/
    private static Date dateFormat(XSSFCell cell) {
        Date dateCellValue = null;
        try {
            dateCellValue = cell.getDateCellValue();
        } catch (Exception e) {
            log.error("时间格式解析错误", e);
        }
        return dateCellValue;
    }

    private static String getEnumValue(String value) {
        if (StrUtil.isBlank(value)) {
            return null;
        }
        if ("是".equals(value)) {
            value = "1";
        } else if ("否".equals(value)) {
            value = "0";
        }
        return value;
    }

}
