package com.air.utils;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.extra.spring.SpringUtil;
import cn.hutool.json.JSONUtil;
import com.air.applets.dto.CoordinatePoint;
import com.air.entity.PolygonGeom;
import com.air.entity.PolygonPoint;
import lombok.extern.slf4j.Slf4j;
import org.locationtech.jts.geom.Coordinate;
import org.locationtech.jts.geom.GeometryFactory;
import org.locationtech.jts.geom.Point;
import org.locationtech.jts.geom.Polygon;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;
import org.springframework.web.util.WebUtils;

import javax.servlet.http.HttpServletRequest;
import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;

/**
 * @author peihao
 * @date 2021-09-14
 **/
@Slf4j
public class GeomUtils {

    /**
     *
     * @param polygonPoints 坐标点位
     * @param lineColor 线条颜色
     * @param lineOpaqueness 线条不透明度
     * @param lineWidth 线条宽度
     * @param fillColor 填充颜色
     * @param fillOpaqueness 填充不透明度
     * @return
     */
    public static PolygonGeom computeGemo(List<PolygonPoint> polygonPoints,String lineColor,Integer lineOpaqueness,Integer lineWidth,
                                          String fillColor,Integer fillOpaqueness){
        PolygonGeom polygonGeom = new PolygonGeom();
        HttpServletRequest request = ServletRequestAttributes.class.cast(RequestContextHolder.getRequestAttributes()).getRequest();
        String s = request.getHeader("request-source");
        String strokeColor;
        String fillColor1;
        if ("wechat_applet".equals(s)){
//            log.info("处理前透明度=={}",lineOpaqueness);
            strokeColor = computeColorWechat(lineColor, lineOpaqueness);
            fillColor1 = computeColorWechat(fillColor, fillOpaqueness);
//            strokeColor =lineColor;
//            fillColor1 = fillColor;
        }else {
            strokeColor = computeColor(lineColor, lineOpaqueness);
            fillColor1 = computeColor(fillColor, fillOpaqueness);
//            strokeColor = computeColorWechats(lineColor, lineOpaqueness);
//            fillColor1 = computeColorWechats(fillColor, fillOpaqueness);
//            strokeColor = lineColor;
//            fillColor1 = fillColor;
        }
        polygonGeom.setStrokeColor(strokeColor);
        polygonGeom.setFillColor(fillColor1);
        polygonGeom.setStrokeWidth(Integer.valueOf(lineWidth));
        polygonGeom.setPoints(polygonPoints);
        return polygonGeom;
    }

    public static CoordinatePoint lonLatConvertPoint(String lonLat){
      //  log.info("范围坐标=={}",lonLat);

        List<String> lonLatList = Arrays.asList(lonLat.split(";"));//将坐标转换为数组

        CoordinatePoint coordinatePoint = new CoordinatePoint();
        //绘图经纬度
        List<PolygonPoint> polygonPoints = new ArrayList<>();
        //坐标数组
        List<List<Double>> coordinates = new ArrayList<>();
        //导航中间点
        List<Double> cenPoint = new ArrayList<>(2);
        //
//        log.info("中心lon经度==={}===中心lat纬度==={}",centerPoint.get("lon"),centerPoint.get("lat"));
        Map<String, Double> centerPoint = getCenterPoint(lonLat);//有些中心不准
//        Map<String, Double> centerPoint = getCenterOfGravityPoint4(lonLat);
//        log.info("中心lon经度==={}===中心lat纬度==={}",centerPoint.get("lon"),centerPoint.get("lat"));
        cenPoint.add(centerPoint.get("lon"));
        cenPoint.add(centerPoint.get("lat"));
        for (int i = 0;i<lonLatList.size();i++){ //处理坐标点
            String[] lntlat = lonLatList.get(i).split(",");
//            log.info("lon经度==={}===lat纬度==={}",lntlat[0],lntlat[1]);
            double lon = Double.parseDouble(lntlat[0]);
            double lat = Double.parseDouble(lntlat[1]);
//            if (i == 0){
//                cenPoint.add(lon);
//                cenPoint.add(lat);
//            }
            PolygonPoint point = new PolygonPoint();
            point.setLongitude(lon);
            point.setLatitude(lat);
            List<Double> coordinate = new ArrayList<>();
            coordinate.add(lon);
            coordinate.add(lat);
            polygonPoints.add(point);
            coordinates.add(coordinate);
        }

        coordinatePoint.setCoordinates(coordinates);
        coordinatePoint.setPolygonPoints(polygonPoints);
        coordinatePoint.setCenPoint(cenPoint);
        return coordinatePoint;
    }

    /**
     * 根据输入的地点坐标计算中心点
     *
     * @param str ( 118.778076,30.905645;118.780764,30.914549;118.782928,30.9186;118.785621,30.92202; )
     * @return
     */
    public static  Map<String,Double> getCenterPoint(String str) {
        String[] arr = str.split(";");
        int total = arr.length;
        double X = 0, Y = 0, Z = 0;
        for (int i = 0; i < arr.length; i++) {
            double lat, lon, x, y, z;
            lon = Double.parseDouble(arr[i].split(",")[0]) * Math.PI / 180;
            lat = Double.parseDouble(arr[i].split(",")[1]) * Math.PI / 180;
            x = Math.cos(lat) * Math.cos(lon);
            y = Math.cos(lat) * Math.sin(lon);
            z = Math.sin(lat);
            X += x;
            Y += y;
            Z += z;
        }

        X = X / total;
        Y = Y / total;
        Z = Z / total;
        double Lon = Math.atan2(Y, X);
        double Hyp = Math.sqrt(X * X + Y * Y);
        double Lat = Math.atan2(Z, Hyp);
  //      log.info("{}",Lat * 180 / Math.PI);
  //      log.info("{}", Lon * 180 / Math.PI);
//        return new GeoCoordinate(Lat * 180 / Math.PI, Lon * 180 / Math.PI);
        Map<String,Double> map = new HashMap<String,Double>();
        map.put("lon", Lon * 180 / Math.PI);
        map.put("lat", Lat * 180 / Math.PI);
        return map;
    }

    //计算内心、质心
    public static Map<String,Double> getCenterOfGravityPoint4(String str ) {
        String[] arr = str.split(";");
//        for (String s : arr) {
//            String[] split = s.split(",");
//        }
        List<Coordinate>  CoordinateList=new ArrayList<>();
        //CoordinateList.add(new Coordinate("经度","纬度"));
        for (String s : arr) {
            String[] split = s.split(",");
            String s1 = split[0];
            String s2 = split[1];
            Double doubleString = Double.parseDouble(s1);
            Double doubler = Double.parseDouble(s2);
            CoordinateList.add(new Coordinate(doubleString,doubler));
        }

        Coordinate[] coordinates = new Coordinate[CoordinateList.size()];
        CoordinateList.toArray(coordinates);
        GeometryFactory geometryFactory = new GeometryFactory();
        //MultiPoint mpoint=geometryFactory.createMultiPointFromCoords(coordinates);//创建多点
        //Point pt=mpoint.getCentroid();//得到多点的质心
        //Point pt=mpoint.getInteriorPoint();//多点内心
        Polygon p=geometryFactory.createPolygon(coordinates);//创建多边形
        //Point pt=p.getCentroid();//多边形质心
        Point pt=p.getInteriorPoint();//多边形内心
        Map<String,Double> map = new HashMap<String,Double>();
        map.put("lon", pt.getX());
        map.put("lat", pt.getY());
//        log.info("{}",pt.getX());
//        log.info("{}",  pt.getY());
        return  map;
    }



//    /**
//     *  根据输入的地点坐标计算中心点
//     * @param str
//     * @return
//     */
//    public static Map<String,Double> getCenterPoint(String str) {
//        String[] arr = str.split(";");
//        int total = arr.length;
//        double X = 0, Y = 0, Z = 0;
//        for(int i=0;i<arr.length;i++){
//            double lat, lon, x, y, z;
//            lon = Double.parseDouble(arr[i].split(",")[0]) * Math.PI / 180;
//            lat = Double.parseDouble(arr[i].split(",")[1]) * Math.PI / 180;
//            x = Math.cos(lat) * Math.cos(lon);
//            y = Math.cos(lat) * Math.sin(lon);
//            z = Math.sin(lat);
//            X += x;
//            Y += y;
//            Z += z;
//        }
//
//        X = X / total;
//        Y = Y / total;
//        Z = Z / total;
//        double Lon = Math.atan2(Y, X);
//        double Hyp = Math.sqrt(X * X + Y * Y);
//        double Lat = Math.atan2(Z, Hyp);
//
//        Map<String,Double> map = new HashMap<String,Double>();
//        map.put("lng", Lon * 180 / Math.PI);
//        map.put("lat", Lat * 180 / Math.PI);
//        return map;
//    }



    public static String computeColor(String color,Integer opaqueness){
        if (StrUtil.isEmpty(color) || opaqueness == null){
            return null;
        }
        List<String> collect = null;
        try {
            String[] cut = StrUtil.cut(StrUtil.subAfter(color, "#", true), 2);
            collect = Arrays.stream(cut).map(e -> String.valueOf(Integer.parseInt(e,16))).collect(Collectors.toList());
        } catch (Exception e) {
            log.error("颜色解析失败",e);
        }

        BigDecimal decimal = new BigDecimal(opaqueness);
        double v = decimal.divide(new BigDecimal(255), 1, BigDecimal.ROUND_HALF_UP).doubleValue();

        StringBuffer colorBuffer = new StringBuffer();
        colorBuffer.append("rgba(").append(CollectionUtil.join(collect, ",")).append(",").append(v).append(")");
        return colorBuffer.toString();
    }

    /**
     * 微信小程序处理
     * @param color
     * @param opaqueness
     * @return
     */
    public static String computeColorWechat(String color,Integer opaqueness){
        if (StrUtil.isEmpty(color) || opaqueness == null){
            return null;
        }
        String hex = Integer.toHexString(opaqueness);
        log.info("透明度后======={}",hex);
        return color+hex;
    }

    /**
     * app处理
     * @param color
     * @param opaqueness
     * @return
     */
    public static String computeColorWechats(String color,Integer opaqueness){
        if (StrUtil.isEmpty(color) || opaqueness == null){
            return null;
        }
        String hex = hex2RGB(color,opaqueness);
        return hex;
    }



    /**
     * 16进制颜色字符串转换成rgb
     * @param hexStr
     * @return rgb
     */
    public static String hex2RGB(String hexStr, Integer lineOpaqueness){
        if(hexStr != null && !"".equals(hexStr) && hexStr.length() == 7){
            String strR = hexStr.substring(1,3);

            String strG = hexStr.substring(3,5);

            String strB = hexStr.substring(5,7);

            int red = Integer.parseInt(strR,16);

            int green = Integer.parseInt(strG,16);

            int blue = Integer.parseInt(strB,16);
            double v = lineOpaqueness.doubleValue()/1000;
            String re ="rgba("+ red +","+green+ ","+blue +","+v+")";
            log.info("rgb==={}"+re);
            return  re;

        }
        return null;
    }// 自定义一个字符缓冲区，


}
