package com.air.utils;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.StrUtil;
import com.air.entity.PolygonPoint;
import com.vividsolutions.jts.geom.*;
import lombok.extern.slf4j.Slf4j;

import java.awt.geom.Point2D;
import java.math.BigDecimal;
import java.util.*;

/**
 * 地图转换工具
 *
 * @author peihao
 * @date 2021-07-19
 **/
@Slf4j
public class WgsUtil {


    public static double pi = 3.1415926535897932384626;
    public static double a = 6378245.0;
    public static double ee = 0.00669342162296594323;

    public static GeometryFactory geometryFactory = new GeometryFactory();

    /**
     * 平均半径,单位：m
     **/
    private static final double EARTH_RADIUS = 6371393;

    public static PolygonPoint wgs84_To_Gcj02(double lat, double lon) {
        PolygonPoint info = new PolygonPoint();
        if (outOfChina(lat, lon)) {
            //info.setChina(false);
            info.setLatitude(lat);
            info.setLongitude(lon);
        } else {
            double dLat = transformLat(lon - 105.0, lat - 35.0);
            double dLon = transformLon(lon - 105.0, lat - 35.0);
            double radLat = lat / 180.0 * pi;
            double magic = Math.sin(radLat);
            magic = 1 - ee * magic * magic;
            double sqrtMagic = Math.sqrt(magic);
            dLat = (dLat * 180.0) / ((a * (1 - ee)) / (magic * sqrtMagic) * pi);
            dLon = (dLon * 180.0) / (a / sqrtMagic * Math.cos(radLat) * pi);
            double mgLat = lat + dLat;
            double mgLon = lon + dLon;
            //info.setChina(true);
            info.setLatitude(mgLat);
            info.setLongitude(mgLon);
        }
        return info;
    }

    public static PolygonPoint gcj02_To_Wgs84(double lat, double lon) {
        PolygonPoint info = new PolygonPoint();
        PolygonPoint gps = transform(lat, lon);
        double lontitude = lon * 2 - gps.getLongitude();
        double latitude = lat * 2 - gps.getLatitude();
        //info.setChina(gps.isChina());
        info.setLatitude(latitude);
        info.setLongitude(lontitude);
        return info;
    }

    private static boolean outOfChina(double lat, double lon) {
        if (lon < 72.004 || lon > 137.8347)
            return true;
        if (lat < 0.8293 || lat > 55.8271)
            return true;
        return false;
    }

    private static double transformLat(double x, double y) {
        double ret = -100.0 + 2.0 * x + 3.0 * y + 0.2 * y * y + 0.1 * x * y
                + 0.2 * Math.sqrt(Math.abs(x));
        ret += (20.0 * Math.sin(6.0 * x * pi) + 20.0 * Math.sin(2.0 * x * pi)) * 2.0 / 3.0;
        ret += (20.0 * Math.sin(y * pi) + 40.0 * Math.sin(y / 3.0 * pi)) * 2.0 / 3.0;
        ret += (160.0 * Math.sin(y / 12.0 * pi) + 320 * Math.sin(y * pi / 30.0)) * 2.0 / 3.0;
        return ret;
    }

    private static double transformLon(double x, double y) {
        double ret = 300.0 + x + 2.0 * y + 0.1 * x * x + 0.1 * x * y + 0.1
                * Math.sqrt(Math.abs(x));
        ret += (20.0 * Math.sin(6.0 * x * pi) + 20.0 * Math.sin(2.0 * x * pi)) * 2.0 / 3.0;
        ret += (20.0 * Math.sin(x * pi) + 40.0 * Math.sin(x / 3.0 * pi)) * 2.0 / 3.0;
        ret += (150.0 * Math.sin(x / 12.0 * pi) + 300.0 * Math.sin(x / 30.0 * pi)) * 2.0 / 3.0;
        return ret;
    }

    private static PolygonPoint transform(double lat, double lon) {
        PolygonPoint info = new PolygonPoint();
        if (outOfChina(lat, lon)) {
            //info.setChina(false);
            info.setLatitude(lat);
            info.setLongitude(lon);
            return info;
        }
        double dLat = transformLat(lon - 105.0, lat - 35.0);
        double dLon = transformLon(lon - 105.0, lat - 35.0);
        double radLat = lat / 180.0 * pi;
        double magic = Math.sin(radLat);
        magic = 1 - ee * magic * magic;
        double sqrtMagic = Math.sqrt(magic);
        dLat = (dLat * 180.0) / ((a * (1 - ee)) / (magic * sqrtMagic) * pi);
        dLon = (dLon * 180.0) / (a / sqrtMagic * Math.cos(radLat) * pi);
        double mgLat = lat + dLat;
        double mgLon = lon + dLon;
        //info.setChina(true);
        info.setLatitude(mgLat);
        info.setLongitude(mgLon);

        return info;
    }

    public static String wgs84_To_Gcj02(String lonLat) {
        try {
            List<String> lonLatList = Arrays.asList(lonLat.split(";"));
            StringBuffer polygon = new StringBuffer();
            for(int i = 0;i<lonLatList.size();i++){
                String[] lntlat = lonLatList.get(i).split(",");
                Double lnt = Double.parseDouble(lntlat[0]);
                Double lat = Double.parseDouble(lntlat[1]);
                PolygonPoint point = wgs84_To_Gcj02(lat, lnt);
                polygon.append(point.getLongitude());
                polygon.append(",");
                polygon.append(point.getLatitude());
                if (i != lonLatList.size()-1){
                    polygon.append(";");
                }
            }
            return polygon.toString();
        } catch (Exception e) {
            log.error("数据坐标转换异常",e);
        }
        return null;
    }
}
